CREATE SCHEMA Strassennetz

-- Historie:
--
-- 03.09.2003 - 1.004 (1.008)
-- Anbindung des Schemas Kostenberechnung
-- Korrektur der historischen Gltigkeitsdaten
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung des Strassenpunkts
-- gem Dokument N0031
--
-- 12.09.2001 - 1.002 (1.004)
-- Referenzen zum Schema Entwurf angepasst
-- in Folge des nderungsantrags A0006
-- Referenzen zum Schema Unfall angepasst
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Strasse, Netzknoten, Nullpunkt, Abschnitt_oder_Ast
-- und Verwaltungsbezirk
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Strassenklasse (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenklasse VALUES ('A','Bundesautobahn')
INSERT INTO Strassenklasse VALUES ('B','Bundesstrae')
INSERT INTO Strassenklasse VALUES ('L','Landesstrae')
INSERT INTO Strassenklasse VALUES ('S','Staatsstrae')
INSERT INTO Strassenklasse VALUES ('K','Kreisstrae')
INSERT INTO Strassenklasse VALUES ('G','Gemeindestrae')

CREATE TABLE Strasse (
   Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strasse_ID) REFERENCES Strasse_abstrakt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Strassenklasse
      CHAR(1) NOT NULL REFERENCES Strassenklasse,
   Strassennummer
      INTEGER NOT NULL, -- Strassennummer
   CHECK ( ( Strassennummer > 0 ) AND ( Strassennummer <= 9999 ) ),
   Zusatzbuchstabe
      CHAR(1), -- Zusatzbuchstabe
   CHECK ( ( Zusatzbuchstabe >= 'A' ) AND ( Zusatzbuchstabe <= 'Z' ) )
)

CREATE TABLE Strasse__hat_Strassenknoten (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Strasse__hat_AoA (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Strasse__hat_BAB_Knotennummer (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Strasse__in_Verwaltungsbezirk (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Verwaltungsbezirk_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Strasse__enthaelt_Block (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Strasse__von_Unfallort (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__einm_am_Anfg_v_Unfall (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__einm_am_Ende_v_Unfall (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__z_Projektkennz_Kostra (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Kostenberechnung.Projektkennzeichnung_Kostra
)

CREATE TABLE Strasse__zu_Baumassnahme (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Baumassnahme
      INTEGER NOT NULL REFERENCES Oekologie.Baumassnahme
)

CREATE TABLE Strasse_abstrakt (
   Strasse_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Art_Strasse_abstrakt
)

CREATE TABLE Art_Strasse_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Strasse_abstrakt VALUES ( 1003, 'Strasse' )
INSERT INTO Art_Strasse_abstrakt VALUES ( 1005, 'Strasse_Symbol' )

CREATE TABLE Strasse_Symbol (
   Strasse_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_Symbol_ID) REFERENCES Strasse_abstrakt,
   Kennung
      VARCHAR(7) NOT NULL
)

CREATE TABLE Verlaufskennzeichen (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verlaufskennzeichen VALUES (1,'Anfang Strae')
INSERT INTO Verlaufskennzeichen VALUES (2,'Ende Strae')
INSERT INTO Verlaufskennzeichen VALUES (3,'Anfang Seitenarm')
INSERT INTO Verlaufskennzeichen VALUES (4,'Ende Seitenarm')
INSERT INTO Verlaufskennzeichen VALUES (5,'Anfang Unterbrechung')
INSERT INTO Verlaufskennzeichen VALUES (6,'Ende Unterbrechung')
INSERT INTO Verlaufskennzeichen VALUES (7,'Anfang getr. verl. Fahrbahn')
INSERT INTO Verlaufskennzeichen VALUES (8,'Ende getr. verl. Fahrbahn')
INSERT INTO Verlaufskennzeichen VALUES (9,'Wiederholung')

CREATE TABLE Strasse_Netzknoten (
   Strasse_Netzknoten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_Netzknoten_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Verlaufskennzeichen
      INTEGER REFERENCES Verlaufskennzeichen
)

CREATE TABLE Strasse_NK__hat_Netzknoten (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Strasse_NK__hat_Vorgaenger (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Strasse_Netzknoten_2
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Strasse_NK__von_Strasse (
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE Knotenart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenart VALUES (1,'plangleich (hhengleich)')
INSERT INTO Knotenart VALUES (2,'planfrei (hhenungleich)')
INSERT INTO Knotenart VALUES (3,'teilplanfrei')
INSERT INTO Knotenart VALUES (0,'fiktiver Netzknoten')

CREATE TABLE Knotenpunktsform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsform VALUES (01,'Einmndung oder Kreuzung von 2-streifigen Straen')
INSERT INTO Knotenpunktsform VALUES (02,'Einmndung oder Kreuzung von 2-bahnigen mit 2-streifigen Straen in der Regel mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (03,'Einmndung oder Kreuzung von zwei 2-bahnigen Straen mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (04,'planfreie Kreuzung von 2-streifigen oder 2-bahnigen Straen')
INSERT INTO Knotenpunktsform VALUES (05,'Kreuzung 2-streifiger Straen als Versatz')
INSERT INTO Knotenpunktsform VALUES (06,'Aufgeweitete Einmndung oder Kreuzung mit mindestens einer 2-bahnigen Strae')
INSERT INTO Knotenpunktsform VALUES (07,'Kreisverkehrsplatz, d < 30 m')
INSERT INTO Knotenpunktsform VALUES (08,'Kreisverkehr, d > 30 m')

CREATE TABLE Knotenpunktsystem (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsystem VALUES (01,'Trompete')
INSERT INTO Knotenpunktsystem VALUES (02,'Birne')
INSERT INTO Knotenpunktsystem VALUES (03,'Dreieck mit 3 zweigeschossigen Bauwerken')
INSERT INTO Knotenpunktsystem VALUES (04,'Dreieck mit 1 dreigeschossigen Bauwerk')
INSERT INTO Knotenpunktsystem VALUES (05,'Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (06,'Kleeblatt, abgewandelt mit halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (07,'Kleeblatt, abgewandelt mit zgiger halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (08,'halbes Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (09,'halbes Kleeblatt, asymmetrisch mit auenliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (10,'halbes Kleeblatt, asymmetrisch mit innen- und hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (11,'halbes Kleeblatt, asymmetrisch mit innen- und nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (12,'halbes Kleeblatt, symmetrisch')
INSERT INTO Knotenpunktsystem VALUES (13,'Raute mit innen- und hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (14,'Raute mit innen- und nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (15,'Raute mit aufgeweiteter Kreuzung')
INSERT INTO Knotenpunktsystem VALUES (16,'Raute mit auenliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (17,'Sondersystem')

CREATE TABLE Netzknoten (
   Netzknoten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Netzknoten_abstrakt,
   Netzknoten_ext
      CHAR(7),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Numerierungsbezirk
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( Numerierungsbezirk >= 1 ) AND ( Numerierungsbezirk <= 9999 ) ),
   Nummer
      INTEGER NOT NULL, -- lfd_NK_Nummer
   CHECK ( ( Nummer >= 1 ) AND ( Nummer <= 999 ) ),
   Knotenart
      INTEGER REFERENCES Knotenart,
   Knotenname
      VARCHAR(30),
   Knotenpunktsform
      INTEGER REFERENCES Knotenpunktsform,
   Knotenpunktsystem
      INTEGER REFERENCES Knotenpunktsystem
)

CREATE TABLE NK__hat_BAB_Knotennummer (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Netzknoten__hat_Nullpunkt (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Netzknoten__in_Strassenknoten (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Strasse_Netzknoten
      INTEGER NOT NULL REFERENCES Strasse_Netzknoten
)

CREATE TABLE Netzknoten__Beginn_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__Ende_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__auf_Trasse (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Trasse
      INTEGER NOT NULL REFERENCES Entwurf.Trasse
)

CREATE TABLE Netzknoten__hat_Wegweiser (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Wegweiser
      INTEGER NOT NULL REFERENCES Statische_Beschilderung.Wegweiser
)

CREATE TABLE Netzknoten_abstrakt (
   Netzknoten_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Art_Netzknoten_abstrakt
)

CREATE TABLE Art_Netzknoten_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(17) NOT NULL
)

INSERT INTO Art_Netzknoten_abstrakt VALUES ( 1011, 'Netzknoten' )
INSERT INTO Art_Netzknoten_abstrakt VALUES ( 1013, 'Netzknoten_Symbol' )

CREATE TABLE Netzknoten_Symbol (
   Netzknoten_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_Symbol_ID) REFERENCES Netzknoten_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE BAB_Knotennummer (
   BAB_Knotennummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (BAB_Knotennummer_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Knotennummer
      INTEGER NOT NULL,
   Buchstabe
      CHAR(1)
)

CREATE TABLE BAB_Knotennummer__auf_Strasse (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE BAB_Knotennummer__von_NK (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Stadium (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Stadium VALUES (00,'unter Verkehr')
INSERT INTO Stadium VALUES (11,'Neubau in Planung')
INSERT INTO Stadium VALUES (12,'Neubau in Ausfhrung')
INSERT INTO Stadium VALUES (20,'Erneuerung/Ersatzneubau in Planung')
INSERT INTO Stadium VALUES (21,'Erneuerung/Ersatzneubau in Ausfhrung')
INSERT INTO Stadium VALUES (30,'Instandsetzung in Planung')
INSERT INTO Stadium VALUES (31,'Instandsetzung in Ausfhrung')

CREATE TABLE Abschnitt_oder_Ast (
   Abschnitt_oder_Ast_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Abschnitt_oder_Ast_ext
      CHAR(16),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast,
   Laenge
      REAL, -- Meter
   Stadium
      INTEGER REFERENCES Stadium,
   Streckenart
      INTEGER,
   Verkehrsfreigabe
      CHAR(10), -- Datum
   CHECK ( Verkehrsfreigabe LIKE '__.__.____' ),
   Abschnittsnummer
      INTEGER -- Abschnitt
)

CREATE TABLE Art_Abschnitt_oder_Ast (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(9) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast VALUES ( 1019, 'Abschnitt' )
INSERT INTO Art_Abschnitt_oder_Ast VALUES ( 1020, 'Ast' )

CREATE TABLE AoA__beginnt_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__endet_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__gehoert_zu_Strasse (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE AoA__hat_Teilabschnitt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse_1
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_1
      REAL, -- Meter
   Station_2
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse_2
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_2
      REAL -- Meter
)

CREATE TABLE AoA__hat_Strassenpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Abschnitt_oder_Ast__z_Baumassn (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Baumassnahme
      INTEGER NOT NULL REFERENCES Oekologie.Baumassnahme
)

CREATE TABLE Abschnitt_oder_Ast_abstrakt (
   Abschnitt_oder_Ast_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Abschnitt_oder_Ast_abstr
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast_abstr
)

CREATE TABLE Art_Abschnitt_oder_Ast_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(25) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1018, 'Abschnitt_oder_Ast_Symbol' )
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1019, 'Abschnitt' )
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1020, 'Ast' )

CREATE TABLE Abschnitt_oder_Ast_Symbol (
   Abschnitt_oder_Ast_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_Symbol_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Kennung
      VARCHAR(16) NOT NULL
)

CREATE TABLE Verkehrliche_Verknuepfung (
   Verkehrliche_Verknuepfung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrliche_Verknuepfung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE VV__von_Strassenelement (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE VV__nach_Strassenelement (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE VV__ueber_Nullpunkt (
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Nullpunkt (
   Nullpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES verallgemeinerter_Nullpunkt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Nullpunkt_abstrakt,
   Nullpunkt_ext
      CHAR(8),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zusatz
      CHAR(1) NOT NULL, -- Nullpunktkennung
   CHECK ( ( ( Zusatz >= 'A' AND Zusatz <= 'Z' ) OR ( Zusatz = ' ' ) ) ),
   zentraler_Nullpunkt
      INTEGER REFERENCES Logical_Types.Boolean
)

CREATE TABLE Nullpunkt__in_Netzknoten (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Nullpunkt__Beginn_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__Ende_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__verbindet_VV (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Verkehrliche_Verknuepfung
      INTEGER NOT NULL REFERENCES Verkehrliche_Verknuepfung
)

CREATE TABLE Nullpunkt__hat_Nullpunktsort (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort
)

CREATE TABLE Nullpunkt_abstrakt (
   Nullpunkt_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Art_Nullpunkt_abstrakt
)

CREATE TABLE Art_Nullpunkt_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Nullpunkt_abstrakt VALUES ( 1022, 'Nullpunkt' )
INSERT INTO Art_Nullpunkt_abstrakt VALUES ( 1024, 'Nullpunkt_Symbol' )

CREATE TABLE Nullpunkt_Symbol (
   Nullpunkt_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_Symbol_ID) REFERENCES Nullpunkt_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Bezugsrichtung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Bezugsrichtung VALUES ('B','beide Richtungen')
INSERT INTO Bezugsrichtung VALUES ('R','in Stationierungsrichtung')
INSERT INTO Bezugsrichtung VALUES ('G','gegen Stationierungsrichtung')

CREATE TABLE Punktobjekt (
   Punktobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobjekt
      INTEGER NOT NULL REFERENCES Art_Punktobjekt,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Art_Punktobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt VALUES ( 1032, 'oertliche_Zuordnung_SP' )
INSERT INTO Art_Punktobjekt VALUES ( 1058, 'Kilometrierung' )
INSERT INTO Art_Punktobjekt VALUES ( 1061, 'GDF_Verbindungspunkt' )
INSERT INTO Art_Punktobjekt VALUES ( 4002, 'Schichtbegrenzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4007, 'Streifenbegrenzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4024, 'Gewaesserkreuzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4025, 'Bahnkreuzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4028, 'Kreuzung_Strasse_Weg' )
INSERT INTO Art_Punktobjekt VALUES ( 4032, 'Fussgaengerueberweg' )
INSERT INTO Art_Punktobjekt VALUES ( 4034, 'Durchlass' )
INSERT INTO Art_Punktobjekt VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7007, 'Bauwerk_Netzzuordnung' )
INSERT INTO Art_Punktobjekt VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Punktobjekt VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Punktobjekt VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 19005, 'Unfallort_Strassenpunkt' )
INSERT INTO Art_Punktobjekt VALUES ( 20012, 'Wirkungsbereich_SP' )
INSERT INTO Art_Punktobjekt VALUES ( 20047, 'Aufstellvorrichtung' )
INSERT INTO Art_Punktobjekt VALUES ( 20055, 'Anordnung_des_Messsystems' )
INSERT INTO Art_Punktobjekt VALUES ( 21014, 'Standort' )
INSERT INTO Art_Punktobjekt VALUES ( 21031, 'stat_verkehrsreg_Beschilderung' )
INSERT INTO Art_Punktobjekt VALUES ( 21042, 'Position' )
INSERT INTO Art_Punktobjekt VALUES ( 32016, 'Standortbeschreibung_Baum' )

CREATE TABLE Punktobjekt_stat (
   Punktobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_stat_ID) REFERENCES Punktobjekt,
   Art_Punktobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_stat
)

CREATE TABLE Art_Punktobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt_stat VALUES ( 1032, 'oertliche_Zuordnung_SP' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 1061, 'GDF_Verbindungspunkt' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 7007, 'Bauwerk_Netzzuordnung' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 19005, 'Unfallort_Strassenpunkt' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 20012, 'Wirkungsbereich_SP' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 20055, 'Anordnung_des_Messsystems' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21014, 'Standort' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21031, 'stat_verkehrsreg_Beschilderung' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21042, 'Position' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 32016, 'Standortbeschreibung_Baum' )

CREATE TABLE Punktobjekt_hist (
   Punktobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Punktobjekt,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Punktobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_hist
)

CREATE TABLE Art_Punktobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Punktobjekt_hist VALUES ( 1058, 'Kilometrierung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4002, 'Schichtbegrenzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4007, 'Streifenbegrenzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4024, 'Gewaesserkreuzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4025, 'Bahnkreuzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4028, 'Kreuzung_Strasse_Weg' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4032, 'Fussgaengerueberweg' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4034, 'Durchlass' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 20047, 'Aufstellvorrichtung' )

CREATE TABLE oertliche_Zuordnung (
   oertliche_Zuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   liegt_auf_Strassenpunkt
      INTEGER REFERENCES oertliche_Zuordnung_SP,
   liegt_auf_nicht_klass_Strasse
      INTEGER REFERENCES nicht_nach_ASB_klass_Strasse,
   CHECK ( ( ( liegt_auf_Strassenpunkt IS NOT NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NOT NULL ) ) AND ( ( liegt_auf_Strassenpunkt IS NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NULL ) ) )
)

CREATE TABLE oertliche_Zuordnung_SP (
   oertliche_Zuordnung_SP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_SP_ID) REFERENCES Punktobjekt_stat
)

CREATE TABLE nicht_nach_ASB_klass_Strasse (
   nicht_n_ASB_klass_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenklasse
      VARCHAR(50) NOT NULL,
   Nummer
      INTEGER NOT NULL,
   Lage
      VARCHAR(28) NOT NULL
)

CREATE TABLE Nullpunktsort (
   Nullpunktsort_ID
      INTEGER NOT NULL PRIMARY KEY,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Nullpunktsort__bei_Nullpunkt (
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Strassenpunkt_PoB (
   Strassenpunkt_PoB_ID
      INTEGER NOT NULL PRIMARY KEY,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Punktobjekt_o_Bereichsobjekt (
   Punktobjekt_o_Bereichsobj_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobj_o_Bereichsobj
      INTEGER NOT NULL REFERENCES Art_Punktobj_o_Bereichsobj,
   ist_Punktobjekt
      INTEGER REFERENCES Strassenpunkt_PoB,
   ist_Bereichsobjekt
      INTEGER REFERENCES Netzbereich,
   CHECK ( (ist_Punktobjekt IS NOT NULL AND ist_Bereichsobjekt IS NULL) OR (ist_Punktobjekt IS NULL AND ist_Bereichsobjekt IS NOT NULL) )
)

CREATE TABLE Art_Punktobj_o_Bereichsobj (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11001, 'Beschilderung_Lichtsignalanl' )
INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11002, 'Fahrbahnmarkierungen' )
INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11003, 'Schutz_und_Leiteinrichtungen' )

CREATE TABLE Netzbereichskomponente (
   Netzbereichskomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzbereichskomponente
      INTEGER NOT NULL REFERENCES Art_Netzbereichskomponente
)

CREATE TABLE Art_Netzbereichskomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Netzbereichskomponente VALUES ( 1039, 'Netzbereich' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1050, 'Teilabschnitt_NB' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1051, 'Strecke' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1052, 'Strecke_SO' )

CREATE TABLE Netzbereich (
   Netzbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Netzbrch__enthaelt_Komponenten (
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich,
   Netzbereichskomponente
      INTEGER REFERENCES Netzbereichskomponente,
   auf_Abschnitt_oder_Ast
      INTEGER REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL, -- Meter
   Abstand_zur_Bestandsachse_1
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_1
      REAL, -- Meter
   Station_2
      REAL, -- Meter
   Abstand_zur_Bestandsachse_2
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_2
      REAL -- Meter
)

CREATE TABLE Bereichsobjekt (
   Bereichsobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Bereichsobjekt
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt
)

CREATE TABLE Art_Bereichsobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt VALUES ( 2005, 'Bundesland' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2006, 'Regierungsbezirk' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2007, 'Kreis_kreisfreie_Stadt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2009, 'Gemeindebezirk' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2012, 'Ortsteil' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2016, 'Land_Ministerium' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2017, 'Regierungspraesidium_Landesamt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2018, 'Amt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2019, 'Meisterei' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2020, 'Kreisverwaltung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2021, 'Gemeindeverwaltung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2023, 'UI_Vereinbarung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2025, 'Baulast' )
INSERT INTO Art_Bereichsobjekt VALUES ( 4020, 'Schutzzone' )

CREATE TABLE Bereichsobj__hat_Netzbereich (
   Bereichsobjekt
      INTEGER NOT NULL REFERENCES Bereichsobjekt,
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich
)

CREATE TABLE Bereichsobjekt_stat (
   Bereichsobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_stat_ID) REFERENCES Bereichsobjekt,
   Art_Bereichsobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_stat
)

CREATE TABLE Art_Bereichsobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

CREATE TABLE Bereichsobjekt_hist (
   Bereichsobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Bereichsobjekt,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Bereichsobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_hist
)

CREATE TABLE Art_Bereichsobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2005, 'Bundesland' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2006, 'Regierungsbezirk' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2007, 'Kreis_kreisfreie_Stadt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2009, 'Gemeindebezirk' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2012, 'Ortsteil' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2016, 'Land_Ministerium' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2017, 'Regierungspraesidium_Landesamt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2018, 'Amt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2019, 'Meisterei' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2020, 'Kreisverwaltung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2021, 'Gemeindeverwaltung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2023, 'UI_Vereinbarung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2025, 'Baulast' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 4020, 'Schutzzone' )

CREATE TABLE Streckenobjekt (
   Streckenobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Streckenobjekt
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt
)

CREATE TABLE Art_Streckenobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Streckenobjekt VALUES ( 1060, 'Block' )
INSERT INTO Art_Streckenobjekt VALUES ( 1065, 'Entwurfselement_Kreisbogen' )
INSERT INTO Art_Streckenobjekt VALUES ( 1066, 'Entwurfselement_Klothoide' )
INSERT INTO Art_Streckenobjekt VALUES ( 1067, 'Entwurfselement_Gerade' )
INSERT INTO Art_Streckenobjekt VALUES ( 2030, 'OD_FS' )
INSERT INTO Art_Streckenobjekt VALUES ( 2032, 'Widmung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3003, 'Anzahl_Fahrstreifen' )
INSERT INTO Art_Streckenobjekt VALUES ( 3005, 'Insassen_min_Anzahl' )
INSERT INTO Art_Streckenobjekt VALUES ( 3006, 'Ueberholverbot' )
INSERT INTO Art_Streckenobjekt VALUES ( 3007, 'max_Hoehe' )
INSERT INTO Art_Streckenobjekt VALUES ( 3008, 'max_Breite' )
INSERT INTO Art_Streckenobjekt VALUES ( 3009, 'max_Laenge' )
INSERT INTO Art_Streckenobjekt VALUES ( 3010, 'max_Gewicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 3011, 'max_Achsgewicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 3012, 'max_Geschwindigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 3013, 'Zugangsbeschraenkung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3014, 'Gesperrt' )
INSERT INTO Art_Streckenobjekt VALUES ( 3016, 'Fkt_d_Verb_im_Knotenpktber' )
INSERT INTO Art_Streckenobjekt VALUES ( 3018, 'Bergpass' )
INSERT INTO Art_Streckenobjekt VALUES ( 3019, 'Verkehrsbedeutung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3020, 'Spur_fuer_Rettungsfahrzeuge' )
INSERT INTO Art_Streckenobjekt VALUES ( 3021, 'Strassenfunktion' )
INSERT INTO Art_Streckenobjekt VALUES ( 3022, 'Aussichtswert' )
INSERT INTO Art_Streckenobjekt VALUES ( 3023, 'Staugefahr' )
INSERT INTO Art_Streckenobjekt VALUES ( 3024, 'gebuehrenpflichtig' )
INSERT INTO Art_Streckenobjekt VALUES ( 3025, 'Durchschnittsgeschwindigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 4001, 'Schicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 4005, 'Querschnittstreifen' )
INSERT INTO Art_Streckenobjekt VALUES ( 4008, 'Bauklasse_Oberbau' )
INSERT INTO Art_Streckenobjekt VALUES ( 4009, 'Bauweise_Oberbau' )
INSERT INTO Art_Streckenobjekt VALUES ( 4010, 'Regelquerschnitt' )
INSERT INTO Art_Streckenobjekt VALUES ( 4011, 'Bahnigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 4013, 'Fahrbahnlaengsneigung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4014, 'Fahrbahnquerneigung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4015, 'Fahrbahntrennung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4016, 'Trassenbreite' )
INSERT INTO Art_Streckenobjekt VALUES ( 4017, 'Fahrbahnbreite' )
INSERT INTO Art_Streckenobjekt VALUES ( 4018, 'Fussweg' )
INSERT INTO Art_Streckenobjekt VALUES ( 4019, 'Radweg' )
INSERT INTO Art_Streckenobjekt VALUES ( 4021, 'Hindernis' )
INSERT INTO Art_Streckenobjekt VALUES ( 5003, 'Nebenanlage' )
INSERT INTO Art_Streckenobjekt VALUES ( 5005, 'Rastanlage_nicht_bew' )
INSERT INTO Art_Streckenobjekt VALUES ( 5006, 'Rastanlage_bew' )
INSERT INTO Art_Streckenobjekt VALUES ( 5007, 'Nebenbetrieb' )
INSERT INTO Art_Streckenobjekt VALUES ( 5008, 'Leitung' )
INSERT INTO Art_Streckenobjekt VALUES ( 5012, 'Markierung' )
INSERT INTO Art_Streckenobjekt VALUES ( 5014, 'Schutzplanke' )
INSERT INTO Art_Streckenobjekt VALUES ( 5015, 'Strassenentwaesserung' )
INSERT INTO Art_Streckenobjekt VALUES ( 6001, 'ZEB_Objekt' )
INSERT INTO Art_Streckenobjekt VALUES ( 7007, 'Bauwerk_Netzzuordnung' )
INSERT INTO Art_Streckenobjekt VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt VALUES ( 12015, 'abgeleitete_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt VALUES ( 17006, 'raeuml_Gueltigkeitsbereich_MZ' )
INSERT INTO Art_Streckenobjekt VALUES ( 20010, 'SB_Wirkungsbereiche' )
INSERT INTO Art_Streckenobjekt VALUES ( 21038, 'raeumlicher_Gueltigkeitsber' )

CREATE TABLE Streckenobjekt__hat_Strecke (
   Streckenobjekt
      INTEGER NOT NULL REFERENCES Streckenobjekt,
   Strecke
      INTEGER NOT NULL REFERENCES Strecke
)

CREATE TABLE Streckenobjekt_stat (
   Streckenobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_stat_ID) REFERENCES Streckenobjekt,
   Art_Streckenobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_stat
)

CREATE TABLE Art_Streckenobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Streckenobjekt_stat VALUES ( 1065, 'Entwurfselement_Kreisbogen' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 1066, 'Entwurfselement_Klothoide' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 1067, 'Entwurfselement_Gerade' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3003, 'Anzahl_Fahrstreifen' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3005, 'Insassen_min_Anzahl' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3006, 'Ueberholverbot' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3007, 'max_Hoehe' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3008, 'max_Breite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3009, 'max_Laenge' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3010, 'max_Gewicht' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3011, 'max_Achsgewicht' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3012, 'max_Geschwindigkeit' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3013, 'Zugangsbeschraenkung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3014, 'Gesperrt' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3016, 'Fkt_d_Verb_im_Knotenpktber' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3018, 'Bergpass' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3019, 'Verkehrsbedeutung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3020, 'Spur_fuer_Rettungsfahrzeuge' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3021, 'Strassenfunktion' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3022, 'Aussichtswert' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3023, 'Staugefahr' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3024, 'gebuehrenpflichtig' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3025, 'Durchschnittsgeschwindigkeit' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4015, 'Fahrbahntrennung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4016, 'Trassenbreite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4017, 'Fahrbahnbreite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4018, 'Fussweg' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4019, 'Radweg' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 5015, 'Strassenentwaesserung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 6001, 'ZEB_Objekt' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7007, 'Bauwerk_Netzzuordnung' )

CREATE TABLE Streckenobjekt_hist (
   Streckenobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Streckenobjekt,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Streckenobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_hist
)

CREATE TABLE Art_Streckenobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Streckenobjekt_hist VALUES ( 1060, 'Block' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 2030, 'OD_FS' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 2032, 'Widmung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4001, 'Schicht' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4005, 'Querschnittstreifen' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4008, 'Bauklasse_Oberbau' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4009, 'Bauweise_Oberbau' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4010, 'Regelquerschnitt' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4011, 'Bahnigkeit' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4013, 'Fahrbahnlaengsneigung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4014, 'Fahrbahnquerneigung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4021, 'Hindernis' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5003, 'Nebenanlage' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5005, 'Rastanlage_nicht_bew' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5006, 'Rastanlage_bew' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5007, 'Nebenbetrieb' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5008, 'Leitung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5012, 'Markierung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5014, 'Schutzplanke' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 12015, 'abgeleitete_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 17006, 'raeuml_Gueltigkeitsbereich_MZ' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 20010, 'SB_Wirkungsbereiche' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 21038, 'raeumlicher_Gueltigkeitsber' )

CREATE TABLE Strecke (
   Strecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strecke_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Strecke_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Strecke__entlang_Teilabschnitt (
   Strecke
      INTEGER NOT NULL REFERENCES Strecke,
   Position
      INTEGER NOT NULL,
   PRIMARY KEY ( Strecke , Position ),
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse_1
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_1
      REAL, -- Meter
   Station_2
      REAL NOT NULL, -- Meter
   Abstand_zur_Bestandsachse_2
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_2
      REAL -- Meter
)

CREATE TABLE Teilnetzkomponente (
   Teilnetzkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Art_Teilnetzkomponente
)

CREATE TABLE Art_Teilnetzkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Teilnetzkomponente VALUES ( 1054, 'Teilnetz' )
INSERT INTO Art_Teilnetzkomponente VALUES ( 1056, 'Route' )
INSERT INTO Art_Teilnetzkomponente VALUES ( 1057, 'Strassenelement' )

CREATE TABLE Teilnetz (
   Teilnetz_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennzeichen_Teilnetz
      VARCHAR(6),
   Beschreibung_Teilnetz
      VARCHAR(60)
)

CREATE TABLE Teilnetz__enthaelt_Komponente (
   Teilnetz
      INTEGER NOT NULL REFERENCES Teilnetz,
   Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Teilnetzkomponente
)

CREATE TABLE Routenkomponente (
   Routenkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Routenkomponente
      INTEGER NOT NULL REFERENCES Art_Routenkomponente
)

CREATE TABLE Art_Routenkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Routenkomponente VALUES ( 1056, 'Route' )
INSERT INTO Art_Routenkomponente VALUES ( 1057, 'Strassenelement' )

CREATE TABLE Routenkomp__hat_Vorgaenger (
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente,
   Routenkomponente_2
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Route (
   Route_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Route_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Route__entlang_Komponente (
   Route
      INTEGER NOT NULL REFERENCES Route,
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Strassenelement (
   Strassenelement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Strassenelement_ext
      CHAR(16),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   RDS_TMC_Code
      VARCHAR(12),
   beginnt_bei_NPO
      INTEGER NOT NULL REFERENCES Nullpunktsort,
   endet_bei_NPO
      INTEGER NOT NULL REFERENCES Nullpunktsort
)

CREATE TABLE Kilometrierung (
   Kilometrierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kilometrierung_ID) REFERENCES Punktobjekt_hist,
   Kilometrierung
      REAL NOT NULL -- Kilometer
)

CREATE TABLE Betriebskilometer__in_Block (
   Betriebskilometer
      INTEGER NOT NULL REFERENCES Kilometrierung,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Block (
   Block_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Block_ID) REFERENCES Streckenobjekt_hist,
   Blocknummer
      INTEGER NOT NULL,
   km_Anfang
      REAL NOT NULL,
   km_Ende
      REAL NOT NULL
)

CREATE TABLE Block__auf_Strasse (
   Block
      INTEGER NOT NULL REFERENCES Block,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE GDF_Verbindungspunkt (
   GDF_Verbindungspunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES Punktobjekt_stat,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (GDF_Verbindungspunkt_ID) REFERENCES verallgemeinerter_Nullpunkt,
   entspricht_Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt
)

CREATE TABLE GDF_Verbindungselement (
   GDF_Verbindungselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (GDF_Verbindungselement_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   beginnt_bei_verallg_Nullpunkt
      INTEGER NOT NULL REFERENCES verallgemeinerter_Nullpunkt,
   endet_bei_verallg_Nullpunkt
      INTEGER NOT NULL REFERENCES verallgemeinerter_Nullpunkt,
   gehoert_zu_Nullpunkt
      INTEGER REFERENCES Nullpunkt,
   entspricht_Strassenelement
      INTEGER REFERENCES Strassenelement,
   CHECK ( (gehoert_zu_Nullpunkt IS NOT NULL AND entspricht_Strassenelement IS NULL) OR (gehoert_zu_Nullpunkt IS NULL AND entspricht_Strassenelement IS NOT NULL) )
)

CREATE TABLE verallgemeinerter_Nullpunkt (
   verallgemeinerter_Nullpunkt_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Entwurfselement (
   Entwurfselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_ID) REFERENCES Streckenobjekt_stat,
   Richtungsw_Tangente_am_Anfang
      REAL, -- Winkel
   beginnt_bei_Vermessungspunkt
      INTEGER NOT NULL,
   endet_bei_Vermessungspunkt
      INTEGER NOT NULL
)

CREATE TABLE Entwurfselement_Kreisbogen (
   Entwurfselement_Kreisbogen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Kreisbogen_ID) REFERENCES Entwurfselement,
   Radius
      REAL NOT NULL -- Meter
)

CREATE TABLE Entwurfselement_Klothoide (
   Entwurfselement_Klothoide_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Klothoide_ID) REFERENCES Entwurfselement,
   Radius_am_Anfang
      REAL NOT NULL, -- Meter
   Radius_am_Ende
      REAL, -- Meter
   Parameter
      REAL NOT NULL -- Meter
)

CREATE TABLE Entwurfselement_Gerade (
   Entwurfselement_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Gerade_ID) REFERENCES Entwurfselement
)

