CREATE SCHEMA Dynamische_Beschilderung

-- Historie:
--
-- 03.09.2003 - 1.003 (1.008)
-- Korrektur der historischen Gltigkeitsdaten
--
-- 31.05.2002 - 1.002 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr Netzknoten
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE dyn_verkehrsreg_Beschilderung (
   dyn_verkehrsreg_Beschilderg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Name
      VARCHAR(50),
   hat_Einsatzdauer
      INTEGER NOT NULL REFERENCES Einsatzdauer
)

CREATE TABLE dyn_vreg_Besch__in_Komb_v_Anlt (
   dyn_verkehrsreg_Beschilderung
      INTEGER NOT NULL REFERENCES dyn_verkehrsreg_Beschilderung,
   Kombination_von_Anlagentypen
      INTEGER NOT NULL REFERENCES Kombination_von_Anlagentypen
)

CREATE TABLE dyn_vreg_Besch__hat_verw_Zuord (
   dyn_verkehrsreg_Beschilderung
      INTEGER NOT NULL REFERENCES dyn_verkehrsreg_Beschilderung,
   verwaltungstechn_Zuordnung_dyn
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordnung_dyn
)

CREATE TABLE dyn_vreg_Besch__hat_Anlagausst (
   dyn_verkehrsreg_Beschilderung
      INTEGER NOT NULL REFERENCES dyn_verkehrsreg_Beschilderung,
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung
)

CREATE TABLE Kombination_von_Anlagentypen (
   Kombination_v_Anlagentypen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kombination_v_Anlagentypen_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE verwaltungstechn_Zuordnung_dyn (
   verwaltungst_Zuordnung_dyn_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungst_Zuordnung_dyn_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE Einsatzdauer (
   Einsatzdauer_ID
      INTEGER NOT NULL PRIMARY KEY,
   Dauer_Art
      INTEGER NOT NULL REFERENCES Art_der_Dauer,
   Dauer_Laenge
      VARCHAR(30) NOT NULL
)

CREATE TABLE Art_der_Dauer (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Dauer VALUES (1,'vorbergehend')
INSERT INTO Art_der_Dauer VALUES (2,'lngerfristig')

CREATE TABLE Streckenbeeinflussung (
   Streckenbeeinflussung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenbeeinflussung_ID) REFERENCES dyn_verkehrsreg_Beschilderung
)

CREATE TABLE Streckbeeinfl__hat_Anlagentyp (
   Streckenbeeinflussung
      INTEGER NOT NULL REFERENCES Streckenbeeinflussung,
   SB_Anlagentyp
      INTEGER NOT NULL REFERENCES SB_Anlagentyp
)

CREATE TABLE Streckbeeinfl__hat_Anzeigzust (
   Streckenbeeinflussung
      INTEGER NOT NULL REFERENCES Streckenbeeinflussung,
   SB_Anzeigezustaende
      INTEGER NOT NULL REFERENCES SB_Anzeigezustaende
)

CREATE TABLE Streckbeeinfl__hat_Wirkbereich (
   Streckenbeeinflussung
      INTEGER NOT NULL REFERENCES Streckenbeeinflussung,
   SB_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES SB_Wirkungsbereiche
)

CREATE TABLE SB_Anlagentyp (
   SB_Anlagentyp_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (SB_Anlagentyp_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Typ
      INTEGER NOT NULL REFERENCES Tab_SB_Anlagentyp
)

CREATE TABLE Tab_SB_Anlagentyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_SB_Anlagentyp VALUES (1,'Geschwindigkeitsbeeinflussung')
INSERT INTO Tab_SB_Anlagentyp VALUES (2,'Stauwarnanlage fest')
INSERT INTO Tab_SB_Anlagentyp VALUES (3,'Stauwarnanlage mobil')
INSERT INTO Tab_SB_Anlagentyp VALUES (4,'Tunnelsteuerung')
INSERT INTO Tab_SB_Anlagentyp VALUES (5,'Fahrstreifenzuteilung / Fahrstreifensperrung')
INSERT INTO Tab_SB_Anlagentyp VALUES (6,'Warnung vor witterungsbedingten Gefahren')
INSERT INTO Tab_SB_Anlagentyp VALUES (7,'Langsamfahrzeugkennung')
INSERT INTO Tab_SB_Anlagentyp VALUES (8,'sonst')

CREATE TABLE SB_Anzeigezustaende (
   SB_Anzeigezustaende_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (SB_Anzeigezustaende_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   StVO_Zeichen
      VARCHAR(99) NOT NULL,
   Zusatzzeichen
      VARCHAR(50) NOT NULL
)

CREATE TABLE SB_Wirkungsbereiche (
   SB_Wirkungsbereiche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (SB_Wirkungsbereiche_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Bereich
      INTEGER NOT NULL REFERENCES Tab_Wirkungsbereich,
   Richtungsangabe
      VARCHAR(28)
)

CREATE TABLE SB_Wirkber__beginnt_b_Strpunkt (
   SB_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES SB_Wirkungsbereiche,
   Wirkungsbereich_SP
      INTEGER NOT NULL REFERENCES Wirkungsbereich_SP
)

CREATE TABLE SB_Wirkber__endet_b_Strpunkt (
   SB_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES SB_Wirkungsbereiche,
   Wirkungsbereich_SP
      INTEGER NOT NULL REFERENCES Wirkungsbereich_SP
)

CREATE TABLE Tab_Wirkungsbereich (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Wirkungsbereich VALUES (1,'Beeinflussungsbereich gilt fr beide Richtungen')
INSERT INTO Tab_Wirkungsbereich VALUES (2,'Beeinflussungsbereich Richtung 1')
INSERT INTO Tab_Wirkungsbereich VALUES (3,'Beeinflussungsbereich Richtung 2')

CREATE TABLE Wirkungsbereich_SP (
   Wirkungsbereich_SP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Wirkungsbereich_SP_ID) REFERENCES Strassennetz.Punktobjekt_stat
)

CREATE TABLE Wechselwegweisung (
   Wechselwegweisung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Wechselwegweisung_ID) REFERENCES dyn_verkehrsreg_Beschilderung,
   Anlagentyp
      INTEGER NOT NULL REFERENCES WW_Anlagentyp
)

CREATE TABLE Wechselwegw__hat_Anzzustaende (
   Wechselwegweisung
      INTEGER NOT NULL REFERENCES Wechselwegweisung,
   WW_Anzeigezustaende
      INTEGER NOT NULL REFERENCES WW_Anzeigezustaende
)

CREATE TABLE Wechselwegw__hat_Wirkungsber (
   Wechselwegweisung
      INTEGER NOT NULL REFERENCES Wechselwegweisung,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES WW_Wirkungsbereiche
)

CREATE TABLE WW_Anzeigezustaende (
   WW_Anzeigezustaende_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (WW_Anzeigezustaende_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzeigezustand
      VARCHAR(99) NOT NULL
)

CREATE TABLE WW_Anlagentyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO WW_Anlagentyp VALUES (1,'additive Wechselwegweisung')
INSERT INTO WW_Anlagentyp VALUES (2,'substitutive Wechselwegweisung')

CREATE TABLE WW_Wirkungsbereiche (
   WW_Wirkungsbereiche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (WW_Wirkungsbereiche_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Bereich
      INTEGER NOT NULL REFERENCES Tab_Wirkungsbereich,
   Richtungsangabe
      VARCHAR(28)
)

CREATE TABLE WW_Wirkungsber__betroffene_BAB (
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES WW_Wirkungsbereiche,
   betroffene_BAB
      VARCHAR(99) NOT NULL
)

CREATE TABLE WW_Wirkungsber__beginnt_bei_NK (
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES WW_Wirkungsbereiche,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Strassennetz.Netzknoten_abstrakt
)

CREATE TABLE WW_Wirkungsber__endet_bei_NK (
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES WW_Wirkungsbereiche,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Strassennetz.Netzknoten_abstrakt
)

CREATE TABLE Knotenpunktbeeinflussung (
   Knotenpunktbeeinflussung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Knotenpunktbeeinflussung_ID) REFERENCES dyn_verkehrsreg_Beschilderung,
   hat_Wirkungsbereich
      INTEGER NOT NULL REFERENCES KB_Wirkungsbereich
)

CREATE TABLE Knotpktbeeinfl__hat_Anlagentyp (
   Knotenpunktbeeinflussung
      INTEGER NOT NULL REFERENCES Knotenpunktbeeinflussung,
   KB_Anlagentyp
      INTEGER NOT NULL REFERENCES KB_Anlagentyp
)

CREATE TABLE Knotpktbeeinfl__hat_Anzeigzust (
   Knotenpunktbeeinflussung
      INTEGER NOT NULL REFERENCES Knotenpunktbeeinflussung,
   KB_Anzeigezustaende
      INTEGER NOT NULL REFERENCES KB_Anzeigezustaende
)

CREATE TABLE KB_Anlagentyp (
   KB_Anlagentyp_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (KB_Anlagentyp_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Typ
      INTEGER NOT NULL REFERENCES Tab_KB_Anlagentyp
)

CREATE TABLE Tab_KB_Anlagentyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_KB_Anlagentyp VALUES (1,'Fahrstreifenzuteilung im Knotenpunkt')
INSERT INTO Tab_KB_Anlagentyp VALUES (2,'Geschwindigkeitsbeeinflussung im Einfdelungsbereich' )
INSERT INTO Tab_KB_Anlagentyp VALUES (3,'Geschwindigkeitswarnanlage')
INSERT INTO Tab_KB_Anlagentyp VALUES (4,'Stauwarnanlage')
INSERT INTO Tab_KB_Anlagentyp VALUES (5,'sonst')

CREATE TABLE KB_Anzeigezustaende (
   KB_Anzeigezustaende_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (KB_Anzeigezustaende_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzeigezustand
      VARCHAR(99) NOT NULL
)

CREATE TABLE KB_Wirkungsbereich (
   KB_Wirkungsbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bereich
      INTEGER NOT NULL REFERENCES Tab_KB_Wirkungsbereich
)

CREATE TABLE KB_Wirkber__ist_richtbez_WB (
   KB_Wirkungsbereich
      INTEGER NOT NULL REFERENCES KB_Wirkungsbereich,
   richtungsbezogener_WB
      INTEGER NOT NULL REFERENCES richtungsbezogener_WB
)

CREATE TABLE KB_Wirkber__ist_astbezog_WB (
   KB_Wirkungsbereich
      INTEGER NOT NULL REFERENCES KB_Wirkungsbereich,
   astbezogener_WB
      INTEGER NOT NULL REFERENCES astbezogener_WB
)

CREATE TABLE KB_Wirkber__hat_Ang_z_Knotpkt (
   KB_Wirkungsbereich
      INTEGER NOT NULL REFERENCES KB_Wirkungsbereich,
   Angaben_zum_Knotenpunkt
      INTEGER NOT NULL REFERENCES Angaben_zum_Knotenpunkt
)

CREATE TABLE Tab_KB_Wirkungsbereich (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_KB_Wirkungsbereich VALUES (1,'Beeinflussungsbereich gilt fr beide Richtungen')
INSERT INTO Tab_KB_Wirkungsbereich VALUES (2,'Beeinflussungsbereich fr eine Richtung')

CREATE TABLE richtungsbezogener_WB (
   richtungsbezogener_WB_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (richtungsbezogener_WB_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Richtung_1
      VARCHAR(30) NOT NULL,
   Richtung_2
      VARCHAR(30)
)

CREATE TABLE astbezogener_WB (
   astbezogener_WB_ID
      INTEGER NOT NULL PRIMARY KEY,
   Rampenbezeichnung
      VARCHAR(50) NOT NULL
)

CREATE TABLE astbezogener_WB__Astkennung (
   astbezogener_WB
      INTEGER NOT NULL REFERENCES astbezogener_WB,
   Astkennung
      VARCHAR(5) NOT NULL
)

CREATE TABLE Angaben_zum_Knotenpunkt (
   Angaben_zum_Knotenpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Angaben_zum_Knotenpunkt_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Netzknotenangabe_1
      INTEGER NOT NULL,
   Netzknotenangabe_2
      INTEGER NOT NULL,
   Netzknotenangabe_3
      INTEGER NOT NULL
)

CREATE TABLE Richtungswechselbetrieb (
   Richtungswechselbetrieb_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Richtungswechselbetrieb_ID) REFERENCES dyn_verkehrsreg_Beschilderung
)

CREATE TABLE Richtwechsbetr__hat_Betrform (
   Richtungswechselbetrieb
      INTEGER NOT NULL REFERENCES Richtungswechselbetrieb,
   Betriebsform
      INTEGER NOT NULL REFERENCES Betriebsform
)

CREATE TABLE Richtwechsbetr__hat_Anzeigzust (
   Richtungswechselbetrieb
      INTEGER NOT NULL REFERENCES Richtungswechselbetrieb,
   RW_Anzeigezustaende
      INTEGER NOT NULL REFERENCES RW_Anzeigezustaende
)

CREATE TABLE Richtwechsbetr__hat_RW_Wirkber (
   Richtungswechselbetrieb
      INTEGER NOT NULL REFERENCES Richtungswechselbetrieb,
   RW_Wirkungsbereich
      INTEGER NOT NULL REFERENCES RW_Wirkungsbereich
)

CREATE TABLE Betriebsform (
   Betriebsform_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Betriebsform_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Betriebsform
      VARCHAR(30) NOT NULL
)

CREATE TABLE RW_Anzeigezustaende (
   RW_Anzeigezustaende_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (RW_Anzeigezustaende_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzeigezustand
      VARCHAR(99) NOT NULL
)

CREATE TABLE RW_Wirkungsbereich (
   RW_Wirkungsbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (RW_Wirkungsbereich_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Bereich
      VARCHAR(30)
)

CREATE TABLE RW_Wirkber__beginnt_bei_Strpkt (
   RW_Wirkungsbereich
      INTEGER NOT NULL REFERENCES RW_Wirkungsbereich,
   Wirkungsbereich_SP
      INTEGER NOT NULL REFERENCES Wirkungsbereich_SP
)

CREATE TABLE RW_Wirkber__endet_bei_Strpkt (
   RW_Wirkungsbereich
      INTEGER NOT NULL REFERENCES RW_Wirkungsbereich,
   Wirkungsbereich_SP
      INTEGER NOT NULL REFERENCES Wirkungsbereich_SP
)

CREATE TABLE Anlagenausstattung (
   Anlagenausstattung_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Anzeigesystem
      INTEGER NOT NULL REFERENCES Anzeigesystem
)

CREATE TABLE Anlausst__hat_Art_d_Stromvers (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Art_der_Stromversorgung
      INTEGER NOT NULL REFERENCES Art_der_Stromversorgung
)

CREATE TABLE Anlausstattung__hat_Steuerung (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Steuerung
      INTEGER NOT NULL REFERENCES Steuerung
)

CREATE TABLE Anlausst__hat_Ueberwach_d_Anl (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Ueberwachung_der_Anlage
      INTEGER NOT NULL REFERENCES Ueberwachung_der_Anlage
)

CREATE TABLE Anlausst__hat_Datenuebertrsyst (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Datenuebertragungssystem
      INTEGER NOT NULL REFERENCES Datenuebertragungssystem
)

CREATE TABLE Anlausstatt__hat_Unterzentrale (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Unterzentrale
      INTEGER NOT NULL REFERENCES Unterzentrale
)

CREATE TABLE Anlagenausstattung__hat_VRZ (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Verkehrsrechnerzentrale
      INTEGER NOT NULL REFERENCES Verkehrsrechnerzentrale
)

CREATE TABLE Anlausstatt__hat_Datenerfeinr (
   Anlagenausstattung
      INTEGER NOT NULL REFERENCES Anlagenausstattung,
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen
)

CREATE TABLE Art_der_Stromversorgung (
   Art_der_Stromversorgung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_Stromversorgung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art
      INTEGER NOT NULL REFERENCES Tab_Art_der_Stromversorgung
)

CREATE TABLE Tab_Art_der_Stromversorgung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Art_der_Stromversorgung VALUES (0,'keine Angaben')
INSERT INTO Tab_Art_der_Stromversorgung VALUES (1,'Zhleranschlusulen (lokale Versorgung)')
INSERT INTO Tab_Art_der_Stromversorgung VALUES (2,'Solarenergie')
INSERT INTO Tab_Art_der_Stromversorgung VALUES (3,'Lngsverkabelung (zentrale Versorgung)')
INSERT INTO Tab_Art_der_Stromversorgung VALUES (4,'Kombination aus 1 und 2')
INSERT INTO Tab_Art_der_Stromversorgung VALUES (5,'sonstige Kombination')

CREATE TABLE Steuerung (
   Steuerung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Steuerung__autom_Steuerung (
   Steuerung
      INTEGER NOT NULL REFERENCES Steuerung,
   automatische_Steuerung
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean
)

CREATE TABLE Steuerung__hat_manu_Steuerung (
   Steuerung
      INTEGER NOT NULL REFERENCES Steuerung,
   manuelle_Steuerung
      INTEGER NOT NULL REFERENCES manuelle_Steuerung
)

CREATE TABLE manuelle_Steuerung (
   manuelle_Steuerung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (manuelle_Steuerung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Steuerung
      INTEGER NOT NULL REFERENCES Tab_Steuerung,
   Bedienung
      VARCHAR(50)
)

CREATE TABLE Tab_Steuerung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Steuerung VALUES (0,'kein manueller Eingriff mglich')
INSERT INTO Tab_Steuerung VALUES (1,'manueller Eingriff ber UZ mglich')
INSERT INTO Tab_Steuerung VALUES (2,'nur manuelle Steuerung')
INSERT INTO Tab_Steuerung VALUES (3,'manueller Eingriff vor Ort und ber Ferneingriff mglich')

CREATE TABLE Datenuebertragungssystem (
   Datenuebertragungssystem_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Datenuebertragungssystem_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Datenuebertragung_SST_UZ
      INTEGER NOT NULL REFERENCES Datenuebertragung_SST_UZ,
   Datenuebertragung_UZ_VRZ
      INTEGER NOT NULL REFERENCES Datenuebertragung_UZ_VRZ
)

CREATE TABLE Datenuebertragung_SST_UZ (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Datenuebertragung_SST_UZ VALUES (0,'keine UZ vorhanden')
INSERT INTO Datenuebertragung_SST_UZ VALUES (1,'AUSA-Netz')
INSERT INTO Datenuebertragung_SST_UZ VALUES (2,'Lngsverkabelung')
INSERT INTO Datenuebertragung_SST_UZ VALUES (3,'Funk')
INSERT INTO Datenuebertragung_SST_UZ VALUES (4,'lokale Steuerung vor Ort')

CREATE TABLE Datenuebertragung_UZ_VRZ (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Datenuebertragung_UZ_VRZ VALUES (0,'kein Anschlu vorhanden')
INSERT INTO Datenuebertragung_UZ_VRZ VALUES (1,'AUSA-Netz')
INSERT INTO Datenuebertragung_UZ_VRZ VALUES (2,'sonst')

CREATE TABLE Unterzentrale (
   Unterzentrale_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Unterzentrale_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Existenz
      INTEGER NOT NULL REFERENCES Existenz_Unterzentrale
)

CREATE TABLE Unterzentrale__Lage (
   Unterzentrale
      INTEGER NOT NULL REFERENCES Unterzentrale,
   Lage
      VARCHAR(99) NOT NULL
)

CREATE TABLE Existenz_Unterzentrale (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Existenz_Unterzentrale VALUES (0,'Anlage ohne Unterzentrale')
INSERT INTO Existenz_Unterzentrale VALUES (1,'Anlage mit einer Unterzentrale')
INSERT INTO Existenz_Unterzentrale VALUES (2,'Anlage wird 2 oder mehr Unterzentralen zugeordnet')

CREATE TABLE Verkehrsrechnerzentrale (
   Verkehrsrechnerzentrale_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrsrechnerzentrale_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Existenz
      INTEGER NOT NULL REFERENCES Exist_Verkehrsrechnerzentrale
)

CREATE TABLE Verkehrsrechnerzentrale__Lage (
   Verkehrsrechnerzentrale
      INTEGER NOT NULL REFERENCES Verkehrsrechnerzentrale,
   Lage
      VARCHAR(30) NOT NULL
)

CREATE TABLE Exist_Verkehrsrechnerzentrale (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Exist_Verkehrsrechnerzentrale VALUES (0,'Anlage ohne Anschlu an eine Verkehrsrechnerzentrale')
INSERT INTO Exist_Verkehrsrechnerzentrale VALUES (1,'Anlage mit Anschlu an eine Verkehrsrechnerzentrale')
INSERT INTO Exist_Verkehrsrechnerzentrale VALUES (2,'Anlage mit Anschlu an 2 oder mehr Verkehrsrechnerzentralen')

CREATE TABLE Ueberwachung_der_Anlage (
   Ueberwachung_der_Anlage_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Ueberwachung_der_Anlage_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_der_Ueberwachung
      VARCHAR(99) NOT NULL
)

CREATE TABLE Anzeigesystem (
   Anzeigesystem_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Anzsystem__hat_Gueltigkbereich (
   Anzeigesystem
      INTEGER NOT NULL REFERENCES Anzeigesystem,
   Gueltigkeitsbereich
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich
)

CREATE TABLE Anzsyst__hat_Wechselverkzeich (
   Anzeigesystem
      INTEGER NOT NULL REFERENCES Anzeigesystem,
   Wechselverkehrszeichen
      INTEGER NOT NULL REFERENCES Wechselverkehrszeichen
)

CREATE TABLE Anzsyst__hat_Aufstellvorrichtg (
   Anzeigesystem
      INTEGER NOT NULL REFERENCES Anzeigesystem,
   Aufstellvorrichtung
      INTEGER NOT NULL REFERENCES Aufstellvorrichtung
)

CREATE TABLE Anzsyst__hat_Anz_d_Anzquerschn (
   Anzeigesystem
      INTEGER NOT NULL REFERENCES Anzeigesystem,
   Anzahl_der_Anzeigequerschnitte
      INTEGER NOT NULL REFERENCES Anzahl_der_Anzeigequerschnitte
)

CREATE TABLE Wechselverkehrszeichen (
   Wechselverkehrszeichen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Wechselverkehrszeichen_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzahl
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl>=0 )
)

CREATE TABLE Wechselverkz__Bauart_d_Zeich (
   Wechselverkehrszeichen
      INTEGER NOT NULL REFERENCES Wechselverkehrszeichen,
   Bauart_des_Zeichens
      INTEGER NOT NULL REFERENCES Bauart_des_Zeichens
)

CREATE TABLE Bauart_des_Zeichens (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Bauart_des_Zeichens VALUES (1,'Faseroptik')
INSERT INTO Bauart_des_Zeichens VALUES (2,'Prismen')
INSERT INTO Bauart_des_Zeichens VALUES (3,'Band / Rollo')
INSERT INTO Bauart_des_Zeichens VALUES (4,'Klapptafel')
INSERT INTO Bauart_des_Zeichens VALUES (5,'mit Warnblinker')
INSERT INTO Bauart_des_Zeichens VALUES (6,'Flietext (frei programmierbare WVZ')
INSERT INTO Bauart_des_Zeichens VALUES (7,'sonst')

CREATE TABLE Aufstellvorrichtung (
   Aufstellvorrichtung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Aufstellvorrichtung_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   Vorrichtung
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean
)

CREATE TABLE Aufstellvorr__hat_Art_d_Aufst (
   Aufstellvorrichtung
      INTEGER NOT NULL REFERENCES Aufstellvorrichtung,
   Art_der_Aufstellung
      INTEGER NOT NULL REFERENCES Art_der_Aufstellung
)

CREATE TABLE Art_der_Aufstellung (
   Art_der_Aufstellung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_Aufstellung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art
      INTEGER NOT NULL REFERENCES Tab_Art_der_Aufstellung
)

CREATE TABLE Tab_Art_der_Aufstellung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Art_der_Aufstellung VALUES (0,'keine Angabe')
INSERT INTO Tab_Art_der_Aufstellung VALUES (1,'an VZB')
INSERT INTO Tab_Art_der_Aufstellung VALUES (2,'in Seitenaufstellung')
INSERT INTO Tab_Art_der_Aufstellung VALUES (3,'an vorh. Bauwerk')
INSERT INTO Tab_Art_der_Aufstellung VALUES (4,'in der Rampe')
INSERT INTO Tab_Art_der_Aufstellung VALUES (5,'im nachgeordneten Netz')
INSERT INTO Tab_Art_der_Aufstellung VALUES (6,'an VZB und in Seitenaufstellung')
INSERT INTO Tab_Art_der_Aufstellung VALUES (7,'an VZB und in der Rampe')
INSERT INTO Tab_Art_der_Aufstellung VALUES (8,'sonstige Kombination')

CREATE TABLE Anzahl_der_Anzeigequerschnitte (
   Anz_der_Anzeigequerschnitte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Anz_der_Anzeigequerschnitte_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzahl
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Anzahl >= 0 ) AND ( Anzahl <= 99 ) ),
   CHECK ( Anzahl>=1 )
)

CREATE TABLE Datenerfassungseinrichtungen (
   Datenerfassungseinrichtung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Datenerfeinr__hat_Gueltigkber (
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen,
   Gueltigkeitsbereich
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich
)

CREATE TABLE Datenerfeinr__hat_Detektmeth (
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen,
   Detektionsmethode
      INTEGER NOT NULL REFERENCES Detektionsmethode
)

CREATE TABLE Datenerfeinr__hat_Anord_d_Msys (
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen,
   Anordnung_des_Messsystems
      INTEGER NOT NULL REFERENCES Anordnung_des_Messsystems
)

CREATE TABLE Datenerfeinr__hat_Art_d_erf_Dn (
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen,
   Art_der_erfassten_Daten
      INTEGER NOT NULL REFERENCES Art_der_erfassten_Daten
)

CREATE TABLE Datenerfeinr__hat_Anz_d_Messqu (
   Datenerfassungseinrichtungen
      INTEGER NOT NULL REFERENCES Datenerfassungseinrichtungen,
   Anzahl_der_Messquerschnitte
      INTEGER NOT NULL REFERENCES Anzahl_der_Messquerschnitte
)

CREATE TABLE Detektionsmethode (
   Detektionsmethode_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Detektionsmethode_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Detektionsmethode_VDE (
   Detektionsmethode
      INTEGER NOT NULL REFERENCES Detektionsmethode,
   Methode_VDE
      INTEGER NOT NULL REFERENCES Methode_VDE
)

CREATE TABLE Detektionsmethode_UDE (
   Detektionsmethode
      INTEGER NOT NULL REFERENCES Detektionsmethode,
   Methode_UDE
      INTEGER NOT NULL REFERENCES Methode_UDE
)

CREATE TABLE Methode_VDE (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Methode_VDE VALUES (1,'Doppelschleife')
INSERT INTO Methode_VDE VALUES (2,'Einfachschleife')
INSERT INTO Methode_VDE VALUES (3,'Radardetektor')
INSERT INTO Methode_VDE VALUES (4,'Infrarotdetektor')
INSERT INTO Methode_VDE VALUES (5,'Ultraschalldetektor')
INSERT INTO Methode_VDE VALUES (6,'Videokamera')
INSERT INTO Methode_VDE VALUES (7,'Laser')
INSERT INTO Methode_VDE VALUES (8,'sonst.')

CREATE TABLE Methode_UDE (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Methode_UDE VALUES (0,'keine Umfelddatenerfassung')
INSERT INTO Methode_UDE VALUES (1,'Sichtdetektor')
INSERT INTO Methode_UDE VALUES (2,'Temperaturmesser')
INSERT INTO Methode_UDE VALUES (3,'Helligkeitsmesser')
INSERT INTO Methode_UDE VALUES (4,'Niederschlagsdetektor')
INSERT INTO Methode_UDE VALUES (5,'Windmesser')
INSERT INTO Methode_UDE VALUES (6,'sonst.')

CREATE TABLE Anordnung_des_Messsystems (
   Anordnung_des_Messsystems_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Anordnung_des_Messsystems_ID) REFERENCES Strassennetz.Punktobjekt_stat
)

CREATE TABLE Anordn_d_Msys__hat_Art_d_Anord (
   Anordnung_des_Messsystems
      INTEGER NOT NULL REFERENCES Anordnung_des_Messsystems,
   Art_der_Anordnung
      INTEGER NOT NULL REFERENCES Art_der_Anordnung
)

CREATE TABLE Art_der_Anordnung (
   Art_der_Anordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_Anordnung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art
      INTEGER NOT NULL REFERENCES Tab_Art_der_Anordnung
)

CREATE TABLE Tab_Art_der_Anordnung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Art_der_Anordnung VALUES (0,'keine Angabe')
INSERT INTO Tab_Art_der_Anordnung VALUES (1,'in der Fahrbahn')
INSERT INTO Tab_Art_der_Anordnung VALUES (2,'an einer VZB')
INSERT INTO Tab_Art_der_Anordnung VALUES (3,'an bestehendem Bauwerk')
INSERT INTO Tab_Art_der_Anordnung VALUES (4,'am Straenrand')
INSERT INTO Tab_Art_der_Anordnung VALUES (5,'Kombination von 1 und 2')
INSERT INTO Tab_Art_der_Anordnung VALUES (6,'Kombination von 1, 2 und 4')
INSERT INTO Tab_Art_der_Anordnung VALUES (7,'Kombination von 1 und 4')
INSERT INTO Tab_Art_der_Anordnung VALUES (8,'sonstige Kombination')

CREATE TABLE Art_der_erfassten_Daten (
   Art_der_erfassten_Daten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_erfassten_Daten_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Verkehrsdaten
      VARCHAR(99) NOT NULL,
   Umfelddaten
      VARCHAR(99) NOT NULL
)

CREATE TABLE Anzahl_der_Messquerschnitte (
   Anzahl_der_Messquerschnitte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Anzahl_der_Messquerschnitte_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Anzahl_d_Messquerschnitte_VDE
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_d_Messquerschnitte_VDE>=0 ),
   Anzahl_d_Messquerschnitte_UDE
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_d_Messquerschnitte_UDE>=0 )
)

CREATE TABLE Gueltigkeitsbereich (
   Gueltigkeitsbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   Aufstelldatum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Aufstelldatum LIKE '__.__.____' ),
   Hersteller
      VARCHAR(50) NOT NULL,
   Abbaudatum
      CHAR(10), -- Datum
   CHECK ( Abbaudatum LIKE '__.__.____' )
)


