CREATE SCHEMA Statische_Beschilderung

-- Historie:
--
-- 03.09.2003 - 1.003 (1.008)
-- Korrekturen bzgl. StVO_Zuordnung gem A0023
-- Korrektur reservierter SQL-Bezeichner gem A0027
--
-- 31.05.2002 - 1.002 (1.007)
-- berarbeitung gem Dokument N0005
-- (statische wegweisende Beschilderung)
--
-- 24.10.2001 - 1.001 (1.005)
-- Korrekturen in Schlsseltabellen
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Wegweiser (
   Wegweiser_ID
      INTEGER NOT NULL PRIMARY KEY,
   Wegweisernummer
      VARCHAR(12), -- Wegweisernummer
   Aufstellungszeitpunkt
      CHAR(10), -- Datum
   CHECK ( Aufstellungszeitpunkt LIKE '__.__.____' ),
   Wegweisertyp
      INTEGER REFERENCES Wegweisertyp,
   lichttechnische_Bauart
      INTEGER REFERENCES lichttechnische_Bauart,
   Sichtrichtung
      CHAR(1) REFERENCES Sichtrichtung,
   StVO_Zeichen
      CHAR(9) REFERENCES StVO_Zeichennummer,
   lichte_Hoehe
      REAL, -- Meter
   Grundfarbe
      INTEGER REFERENCES Grundfarbe_Wegweiser,
   Reiter
      INTEGER REFERENCES Logical_Types.Boolean,
   Kommentar
      VARCHAR(255),
   auf_Verkehrszeichentraeger
      INTEGER NOT NULL REFERENCES Verkehrszeichentraeger,
   in_komplexem_Wegweiser
      INTEGER REFERENCES komplexer_Wegweiser,
   UNIQUE ( Wegweisernummer ) 
)

CREATE TABLE Wegweiser__Bild (
   Wegweiser
      INTEGER NOT NULL REFERENCES Wegweiser,
   Wegweiserbild
      INTEGER NOT NULL REFERENCES Wegweiserbild
)

CREATE TABLE Wegweiser__gehoert_zu_Knoten (
   Wegweiser
      INTEGER NOT NULL REFERENCES Wegweiser,
   Netzknoten
      INTEGER NOT NULL REFERENCES Strassennetz.Netzknoten
)

CREATE TABLE komplexer_Wegweiser (
   komplexer_Wegweiser_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Wegweiserbild (
   Wegweiserbild_ID
      INTEGER NOT NULL PRIMARY KEY,
   Foto
      VARCHAR(255) NOT NULL, -- Bilddatei
   Bildart
      INTEGER REFERENCES Bildart
)

CREATE TABLE Bildart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Bildart VALUES (1,'Vorderansicht')
INSERT INTO Bildart VALUES (2,'Umgebungsansicht')
INSERT INTO Bildart VALUES (3,'Rckansicht')

CREATE TABLE Wegweisertyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Wegweisertyp VALUES (1,'Ankndigung')
INSERT INTO Wegweisertyp VALUES (2,'Vorwegweiser')
INSERT INTO Wegweisertyp VALUES (3,'Pfeilwegweiser')
INSERT INTO Wegweisertyp VALUES (4,'Wegweiser gem Z. 332 StVO')
INSERT INTO Wegweisertyp VALUES (5,'kompakter Tabellenwegweiser')
INSERT INTO Wegweisertyp VALUES (6,'teilaufgelster Tabellenwegweiser')
INSERT INTO Wegweisertyp VALUES (7,'aufgelster Tabellenwegweiser')
INSERT INTO Wegweisertyp VALUES (8,'Ortstafel')
INSERT INTO Wegweisertyp VALUES (9,'Ortsendetafel')
INSERT INTO Wegweisertyp VALUES (10,'Entfernungstafel')
INSERT INTO Wegweisertyp VALUES (11,'Planskizze')
INSERT INTO Wegweisertyp VALUES (12,'Gabelungswegweiser')
INSERT INTO Wegweisertyp VALUES (13,'Sortierwegweiser')
INSERT INTO Wegweisertyp VALUES (14,'Ortshinweistafel')
INSERT INTO Wegweisertyp VALUES (15,'Straennamensschild')
INSERT INTO Wegweisertyp VALUES (16,'sonstiges Hinweisschild, z.B. Hausnummerschild')

CREATE TABLE lichttechnische_Bauart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO lichttechnische_Bauart VALUES (1,'Reflexstoffe mit eingebundenen Mikroglaskugeln')
INSERT INTO lichttechnische_Bauart VALUES (2,'Reflexstoffe mit eingekapselten Mikroglaskugeln')
INSERT INTO lichttechnische_Bauart VALUES (3,'Reflexstoffe auf der Basis von Mikroprismen')
INSERT INTO lichttechnische_Bauart VALUES (4,'von auen oder von innen beleuchtet')

CREATE TABLE Sichtrichtung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Sichtrichtung VALUES ('R','in Stationierungsrichtung')
INSERT INTO Sichtrichtung VALUES ('G','gegen Stationierungsrichtung')
INSERT INTO Sichtrichtung VALUES ('B','in beide Richtungen')

CREATE TABLE StVO_Zeichennummer (
   Kennung
      CHAR(9) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO StVO_Zeichennummer VALUES ('310','Ortstafel')
INSERT INTO StVO_Zeichennummer VALUES ('311','Ortsendetafel')
INSERT INTO StVO_Zeichennummer VALUES ('332','Ausfahrt von der Autobahn')
INSERT INTO StVO_Zeichennummer VALUES ('333','Ausfahrt von der Autobahn')
INSERT INTO StVO_Zeichennummer VALUES ('385','Ortshinweistafel')
INSERT INTO StVO_Zeichennummer VALUES ('415','Wegweiser auf Bundesstraen')
INSERT INTO StVO_Zeichennummer VALUES ('418','Wegweiser auf sonstigen Straen mit grerer Verkehrsbedeutung')
INSERT INTO StVO_Zeichennummer VALUES ('419','Wegweiser auf sonstigen Straen mit geringerer Verkehrsbedeutung')
INSERT INTO StVO_Zeichennummer VALUES ('430','Wegweiser zur Autobahn')
INSERT INTO StVO_Zeichennummer VALUES ('432','Wegweiser zu innerrtlichen Zielen und zu Einrichtungen mit erheblicher Verkehrsbedeutung')
INSERT INTO StVO_Zeichennummer VALUES ('434','Wegweisertafel')
INSERT INTO StVO_Zeichennummer VALUES ('435','Wegweiser innerorts')
INSERT INTO StVO_Zeichennummer VALUES ('436','Wegweiser innerorts')
INSERT INTO StVO_Zeichennummer VALUES ('437','Straennamensschild')
INSERT INTO StVO_Zeichennummer VALUES ('438','Vorwegweiser')
INSERT INTO StVO_Zeichennummer VALUES ('439','Vorwegweiser (frhzeitige Einordnung)')
INSERT INTO StVO_Zeichennummer VALUES ('440','Vorwegweiser zur Autobahn')
INSERT INTO StVO_Zeichennummer VALUES ('448','Ankndigungstafel auf Autobahnen')
INSERT INTO StVO_Zeichennummer VALUES ('448.1','Autohof')
INSERT INTO StVO_Zeichennummer VALUES ('449','Vorwegweiser auf Autobahnen')
INSERT INTO StVO_Zeichennummer VALUES ('453','Entfernungstafel auf Autobahnen')
INSERT INTO StVO_Zeichennummer VALUES ('458','Planskizze')
INSERT INTO StVO_Zeichennummer VALUES ('999','sonst, z.B. Hausnummerschild')

CREATE TABLE Grundfarbe_Wegweiser (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Grundfarbe_Wegweiser VALUES (1,'blau')
INSERT INTO Grundfarbe_Wegweiser VALUES (2,'gelb')
INSERT INTO Grundfarbe_Wegweiser VALUES (3,'wei')
INSERT INTO Grundfarbe_Wegweiser VALUES (4,'braun')
INSERT INTO Grundfarbe_Wegweiser VALUES (5,'grn')
INSERT INTO Grundfarbe_Wegweiser VALUES (6,'mehrfarbig')

CREATE TABLE Verkehrszeichentraeger (
   Verkehrszeichentraeger_ID
      INTEGER NOT NULL PRIMARY KEY,
   Breite
      REAL, -- Meter
   Hoehe
      REAL, -- Meter
   an_Aufstellvorrichtung
      INTEGER NOT NULL REFERENCES Aufstellvorrichtung_VZT
)

CREATE TABLE Aufstellvorrichtung_VZT (
   Aufstellvorrichtung_VZT_ID
      INTEGER NOT NULL PRIMARY KEY,
   Durchmesser
      REAL, -- Millimeter
   CHECK ( Durchmesser >= 0 ),
   Dicke
      REAL, -- Millimeter
   CHECK ( Dicke >= 0 ),
   Hoehe
      REAL, -- Meter
   Art_der_Aufstellvorrichtung
      INTEGER REFERENCES Art_der_Aufstellvorrichtung,
   Material_Aufstellvorrichtung
      INTEGER REFERENCES Material_Aufstellvorrichtung,
   hat_Standort
      INTEGER NOT NULL REFERENCES Standort
)

CREATE TABLE Art_der_Aufstellvorrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Aufstellvorrichtung VALUES (1,'Rohrpfosten')
INSERT INTO Art_der_Aufstellvorrichtung VALUES (2,'Gabelrohrstnder')
INSERT INTO Art_der_Aufstellvorrichtung VALUES (3,'Kragarm')
INSERT INTO Art_der_Aufstellvorrichtung VALUES (4,'Verkehrszeichenbrcke')
INSERT INTO Art_der_Aufstellvorrichtung VALUES (5,'Hauswand')
INSERT INTO Art_der_Aufstellvorrichtung VALUES (6,'sonstiges')

CREATE TABLE Material_Aufstellvorrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Material_Aufstellvorrichtung VALUES (1,'Aluminium')
INSERT INTO Material_Aufstellvorrichtung VALUES (2,'feuerverzinkter Stahl')
INSERT INTO Material_Aufstellvorrichtung VALUES (3,'Beton')

CREATE TABLE Standort (
   Standort_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Standort_ID) REFERENCES Strassennetz.Punktobjekt_stat
)

CREATE TABLE Wegweiserinhalt (
   Wegweiserinhalt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Inhaltstyp
      INTEGER REFERENCES Inhaltstyp,
   Schriftart
      INTEGER REFERENCES Schriftart,
   Schriftfarbe
      INTEGER REFERENCES Schriftfarbe,
   Schriftgroesse
      INTEGER REFERENCES Schriftgroesse,
   Distanz_zum_Entscheidungspunkt
      REAL, -- Meter
   Entfernung_zum_Ziel
      REAL, -- Kilometer
   graphisches_Symbol
      INTEGER REFERENCES graphisches_Symbol,
   Strassennummer
      VARCHAR(255),
   Knotennummer
      INTEGER,
   StVO_Zeichennummer
      VARCHAR(255),
   Grundfarbe
      INTEGER REFERENCES Grundfarbe_Wegweiserinhalt,
   Pfeilart
      INTEGER REFERENCES Pfeilart,
   Pfeilgrundform
      INTEGER REFERENCES Pfeilgrundform,
   Pfeilspitze
      INTEGER REFERENCES Pfeilspitze,
   Pfeilschaft
      INTEGER REFERENCES Pfeilschaft,
   Kommentar
      VARCHAR(255),
   mit_Zielangabe
      INTEGER REFERENCES Zielangabe,
   in_komplexem_Wegweiserinhalt
      INTEGER REFERENCES komplexer_Wegweiserinhalt,
   in_Wegweiser
      INTEGER NOT NULL REFERENCES Wegweiser
)

CREATE TABLE Wegwinhalt__von_Strassenelem (
   Wegweiserinhalt
      INTEGER NOT NULL REFERENCES Wegweiserinhalt,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassennetz.Strassenelement
)

CREATE TABLE Wegwinhalt__nach_Strassenelem (
   Wegweiserinhalt
      INTEGER NOT NULL REFERENCES Wegweiserinhalt,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassennetz.Strassenelement
)

CREATE TABLE komplexer_Wegweiserinhalt (
   komplexer_Wegweiserinhalt_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Inhaltstyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Inhaltstyp VALUES (1,'Zielangabe')
INSERT INTO Inhaltstyp VALUES (2,'graphisches Symbol')
INSERT INTO Inhaltstyp VALUES (3,'Nummernzeichen A')
INSERT INTO Inhaltstyp VALUES (4,'Nummernzeichen B')
INSERT INTO Inhaltstyp VALUES (5,'Nummernzeichen E')
INSERT INTO Inhaltstyp VALUES (6,'Nummernzeichen U')
INSERT INTO Inhaltstyp VALUES (7,'Pfeil')
INSERT INTO Inhaltstyp VALUES (8,'StVO-Zeichen')
INSERT INTO Inhaltstyp VALUES (9,'Knotennummer')
INSERT INTO Inhaltstyp VALUES (10,'Entfernungsangabe')

CREATE TABLE Schriftart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Schriftart VALUES (1,'Mittelschrift')
INSERT INTO Schriftart VALUES (2,'Engschrift')
INSERT INTO Schriftart VALUES (3,'sonstige')

CREATE TABLE Schriftfarbe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Schriftfarbe VALUES (1,'wei')
INSERT INTO Schriftfarbe VALUES (2,'schwarz')
INSERT INTO Schriftfarbe VALUES (3,'gelb')

CREATE TABLE Schriftgroesse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Schriftgroesse VALUES (1,'84 mm')
INSERT INTO Schriftgroesse VALUES (2,'105 mm')
INSERT INTO Schriftgroesse VALUES (3,'126 mm')
INSERT INTO Schriftgroesse VALUES (4,'140 mm')
INSERT INTO Schriftgroesse VALUES (5,'175 mm')
INSERT INTO Schriftgroesse VALUES (6,'210 mm')
INSERT INTO Schriftgroesse VALUES (7,'280 mm')
INSERT INTO Schriftgroesse VALUES (8,'350 mm')
INSERT INTO Schriftgroesse VALUES (9,'420 mm')
INSERT INTO Schriftgroesse VALUES (10,'490 mm')
INSERT INTO Schriftgroesse VALUES (11,'sonstige')

CREATE TABLE Grundfarbe_Wegweiserinhalt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (1,'blau')
INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (2,'gelb')
INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (3,'wei')
INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (4,'braun')
INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (5,'grn')
INSERT INTO Grundfarbe_Wegweiserinhalt VALUES (6,'mehrfarbig')

CREATE TABLE graphisches_Symbol (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO graphisches_Symbol VALUES (1,'Polizeistation')
INSERT INTO graphisches_Symbol VALUES (2,'"Erste Hilfe"-Station')
INSERT INTO graphisches_Symbol VALUES (3,'Informationsstelle')
INSERT INTO graphisches_Symbol VALUES (4,'Tankstelle')
INSERT INTO graphisches_Symbol VALUES (5,'Gasthaus')
INSERT INTO graphisches_Symbol VALUES (6,'Verkaufskiosk')
INSERT INTO graphisches_Symbol VALUES (7,'Motel, Hotel')
INSERT INTO graphisches_Symbol VALUES (8,'Notrufsule')
INSERT INTO graphisches_Symbol VALUES (9,'Fernsprecher')
INSERT INTO graphisches_Symbol VALUES (10,'Toiletten')
INSERT INTO graphisches_Symbol VALUES (11,'Behindertentoiletten')
INSERT INTO graphisches_Symbol VALUES (12,'Rollstuhlfahrersymbol')
INSERT INTO graphisches_Symbol VALUES (13,'Flughafen')
INSERT INTO graphisches_Symbol VALUES (14,'Hafen, Fhrhafen, Fhre')
INSERT INTO graphisches_Symbol VALUES (15,'Autobahnkapelle')
INSERT INTO graphisches_Symbol VALUES (16,'Personenkraftwagen')
INSERT INTO graphisches_Symbol VALUES (17,'Lastkraftwagen')
INSERT INTO graphisches_Symbol VALUES (18,'Kraftomnibus')
INSERT INTO graphisches_Symbol VALUES (19,'Personenkraftwagen mit Anhnger')
INSERT INTO graphisches_Symbol VALUES (20,'Lastkraftwagen mit Anhnger')
INSERT INTO graphisches_Symbol VALUES (21,'Autobahn')
INSERT INTO graphisches_Symbol VALUES (22,'Autobahnausfahrt')
INSERT INTO graphisches_Symbol VALUES (23,'Autobahnkreuz oder Autobahndreieck')
INSERT INTO graphisches_Symbol VALUES (24,'Parkplatz')
INSERT INTO graphisches_Symbol VALUES (25,'Werkstatt')
INSERT INTO graphisches_Symbol VALUES (26,'Autohof')

CREATE TABLE Pfeilart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Pfeilart VALUES (1,'Langpfeil')
INSERT INTO Pfeilart VALUES (2,'Kurzpfeil')
INSERT INTO Pfeilart VALUES (3,'ISO-Pfeil')

CREATE TABLE Pfeilgrundform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Pfeilgrundform VALUES (1,'Geradeauspfeil')
INSERT INTO Pfeilgrundform VALUES (2,'Schrgpfeil links')
INSERT INTO Pfeilgrundform VALUES (3,'Schrgpfeil rechts')
INSERT INTO Pfeilgrundform VALUES (4,'Querpfeil links')
INSERT INTO Pfeilgrundform VALUES (5,'Querpfeil rechts')
INSERT INTO Pfeilgrundform VALUES (6,'gebogener Pfeil links')
INSERT INTO Pfeilgrundform VALUES (7,'gebogener Pfeil rechts')
INSERT INTO Pfeilgrundform VALUES (8,'Wendepfeil')

CREATE TABLE Pfeilspitze (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Pfeilspitze VALUES (1,'Herzpfeil')
INSERT INTO Pfeilspitze VALUES (2,'ISO-Pfeil')

CREATE TABLE Pfeilschaft (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Pfeilschaft VALUES (1,'konischer Schaft')
INSERT INTO Pfeilschaft VALUES (2,'gerader Schaft')

CREATE TABLE Zielangabe (
   Zielangabe_ID
      INTEGER NOT NULL PRIMARY KEY,
   Text
      VARCHAR(255) NOT NULL,
   Zielkategorie
      INTEGER REFERENCES Zielkategorie,
   Kommentar
      VARCHAR(255)
)

CREATE TABLE Referenzzielangabe (
   Referenzzielangabe_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Referenzzielangabe_ID) REFERENCES Zielangabe
)

CREATE TABLE Synonym_Zielangabe (
   Synonym_Zielangabe_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Synonym_Zielangabe_ID) REFERENCES Zielangabe,
   zu_Referenz
      INTEGER NOT NULL REFERENCES Referenzzielangabe
)

CREATE TABLE Zielkategorie (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zielkategorie VALUES (1,'Strae')
INSERT INTO Zielkategorie VALUES (2,'Gemeinde')
INSERT INTO Zielkategorie VALUES (3,'Industrie-/Gewerbegebiete')
INSERT INTO Zielkategorie VALUES (4,'Verkehrsverknpfungspunkte (Flughafen, Hafen, Fhre, P+R, GVZ)')
INSERT INTO Zielkategorie VALUES (5,'Sport/Freizeit')
INSERT INTO Zielkategorie VALUES (6,'ffentliche Einrichtungen (Krankenhuser, Universitten, Verwaltungssitze)')
INSERT INTO Zielkategorie VALUES (7,'private Ziele (Messen, Firmen, Einkaufszentren)')
INSERT INTO Zielkategorie VALUES (8,'Knotenpunkte')
INSERT INTO Zielkategorie VALUES (9,'auslndische Ziele (Gemeinden, Staaten)')
INSERT INTO Zielkategorie VALUES (10,'sonstiges')

CREATE TABLE stat_verkehrsreg_Beschilderung (
   stat_verkehrsreg_Beschildrg_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (stat_verkehrsreg_Beschildrg_ID) REFERENCES Strassennetz.Punktobjekt_stat,
   Fahrtrichtung_WB
      VARCHAR(30),
   hat_Standort_Beschilderung
      INTEGER NOT NULL REFERENCES Standort_Beschilderung
)

CREATE TABLE stat_verkreg_Besch__hat_Gueltb (
   stat_verkehrsreg_Beschilderung
      INTEGER NOT NULL REFERENCES stat_verkehrsreg_Beschilderung,
   Gueltigkeitsbereich_VRB
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich_VRB
)

CREATE TABLE Standort_Beschilderung (
   Standort_Beschilderung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Aufstellart
      INTEGER NOT NULL REFERENCES Aufstellart,
   richtungsbezogene_Ausfuehrung
      INTEGER NOT NULL REFERENCES richtungsbezogene_Ausfuehrung,
   hat_Position
      INTEGER REFERENCES Position,
   hat_StVO_Zuordnung
      INTEGER NOT NULL REFERENCES StVO_Zuordnung
)

CREATE TABLE Standort_Besch__techn_Ausfuehr (
   Standort_Beschilderung
      INTEGER NOT NULL REFERENCES Standort_Beschilderung,
   technische_Ausfuehrung
      VARCHAR(99) NOT NULL
)

CREATE TABLE Standort_Besch__hat_Numerierg (
   Standort_Beschilderung
      INTEGER NOT NULL REFERENCES Standort_Beschilderung,
   Numerierung
      INTEGER NOT NULL REFERENCES Numerierung
)

CREATE TABLE Standort_Besch__hat_verkreg_F (
   Standort_Beschilderung
      INTEGER NOT NULL REFERENCES Standort_Beschilderung,
   verkehrsregelnde_Funktion
      INTEGER NOT NULL REFERENCES verkehrsregelnde_Funktion
)

CREATE TABLE Aufstellart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Aufstellart VALUES (1,'Gabelstnder')
INSERT INTO Aufstellart VALUES (2,'Ausleger rechts')
INSERT INTO Aufstellart VALUES (3,'Ausleger links')
INSERT INTO Aufstellart VALUES (4,'Ausleger seitlich rechts')
INSERT INTO Aufstellart VALUES (5,'Ausleger seitlich links')
INSERT INTO Aufstellart VALUES (6,'Ausleger seitlich hoch')
INSERT INTO Aufstellart VALUES (7,'Schilderbrcke')
INSERT INTO Aufstellart VALUES (8,'Klappschild')

CREATE TABLE verkehrsregelnde_Funktion (
   verkehrsregelnde_Funktion_ID
      INTEGER NOT NULL PRIMARY KEY,
   Funktion
      INTEGER NOT NULL REFERENCES Funktion_verkehrsregelnd,
   Paragraph
      INTEGER
)

CREATE TABLE Funktion_verkehrsregelnd (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(40) NOT NULL
)

INSERT INTO Funktion_verkehrsregelnd VALUES (1,'Gefahrzeichen')
INSERT INTO Funktion_verkehrsregelnd VALUES (2,'Vorschriftszeichen')
INSERT INTO Funktion_verkehrsregelnd VALUES (3,'Richtzeichen')
INSERT INTO Funktion_verkehrsregelnd VALUES (4,'Zusatzzeichen')
INSERT INTO Funktion_verkehrsregelnd VALUES (5,'Kombinationen aus mehreren Zeichen')

CREATE TABLE StVO_Zuordnung (
   StVO_Zuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   StVO_Zeichen
      INTEGER NOT NULL,
   Zusatzzeichen_1
      INTEGER,
   Zusatzzeichen_2
      INTEGER
)

CREATE TABLE Gueltigkeitsbereich_VRB (
   Gueltigkeitsbereich_VRB_ID
      INTEGER NOT NULL PRIMARY KEY,
   verkehrssituationsabh_GB
      VARCHAR(50)
)

CREATE TABLE Gueltkber_VRB__verkartabh_GB (
   Gueltigkeitsbereich_VRB
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich_VRB,
   verkehrsartabhaengiger_GB
      VARCHAR(50) NOT NULL
)

CREATE TABLE Gueltkber_VRB__ist_raueml_GB (
   Gueltigkeitsbereich_VRB
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich_VRB,
   raeumlicher_Gueltigkeitsber
      INTEGER NOT NULL REFERENCES raeumlicher_Gueltigkeitsber
)

CREATE TABLE Gueltkber_VRB__ist_zeitl_GB (
   Gueltigkeitsbereich_VRB
      INTEGER NOT NULL REFERENCES Gueltigkeitsbereich_VRB,
   zeitlicher_Gueltigkeitsber
      INTEGER NOT NULL REFERENCES zeitlicher_Gueltigkeitsber
)

CREATE TABLE raeumlicher_Gueltigkeitsber (
   raeumlicher_Gueltigkeitsber_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (raeumlicher_Gueltigkeitsber_ID) REFERENCES Strassennetz.Streckenobjekt_hist
)

CREATE TABLE zeitlicher_Gueltigkeitsber (
   zeitlicher_Gueltigkeitsber_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (zeitlicher_Gueltigkeitsber_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   zeitlicher_Bereich
      VARCHAR(30) NOT NULL
)

CREATE TABLE richtungsbezogene_Ausfuehrung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO richtungsbezogene_Ausfuehrung VALUES (1,'richtungsbezogen')
INSERT INTO richtungsbezogene_Ausfuehrung VALUES (2,'spur- bzw. fahrstreifenbezogen')

CREATE TABLE Numerierung (
   Numerierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Plannummer
      INTEGER NOT NULL, -- TK25_Blattnummer
   CHECK ( ( Plannummer >= 1 ) AND ( Plannummer <= 9999 ) ),
   Standort_Nummer
      INTEGER
)

CREATE TABLE Position (
   Position_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Position_ID) REFERENCES Strassennetz.Punktobjekt_stat
)


