
CREATE SCHEMA Grunderwerb

-- Historie:
--
-- 03.09.2003 - 1.005 (1.008)
-- Ergnzung von Flchengeometrie fr Erwerbsflaeche
-- und Nutzungsart_Teilflaeche
--
-- 31.05.2002 - 1.004 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 24.10.2001 - 1.003 (1.005)
-- Korrekturen in Schlsseltabellen
--
-- 12.09.2001 - 1.002 (1.004)
-- Flurstueck, Flur und Gemarkung in neues Schema Kataster verlegt
--
-- 17.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Kreis_kreisfreie_Stadt/Gemeinde (Verwaltungsbezirk)
--
-- Schlssel-Felder in Schlsseltabellen einheitlich
-- in 'Kennung' umbenannt
--
-- 29.10.2000 - 1.000 (1.001)
-- Schema in den OKSTRA integriert


CREATE TABLE Attribut_Flurstueck (
   Attribut_Flurstueck_ID
      INTEGER NOT NULL PRIMARY KEY,
   Attributname
      VARCHAR(100) NOT NULL,
   Attributdatum
      CHAR(10), -- Datum
   CHECK ( Attributdatum LIKE '__.__.____' ),
   Attributstatus
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Attributtext
      VARCHAR(255),
   von_Flurstueck
      INTEGER NOT NULL REFERENCES Kataster.Flurstueck
)

CREATE TABLE Erwerbsflaeche (
   Erwerbsflaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Erwerbsflaeche_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Erwerbsart
      CHAR(1) NOT NULL REFERENCES Erwerbsart,
   Erwerbszweck
      CHAR(1) REFERENCES Erwerbszweck,
   GE_Massnahme
      CHAR(10) REFERENCES GE_Massnahme,
   Bedarfsflaeche
      REAL, -- Quadratmeter
   CHECK ( Bedarfsflaeche>=0 ),
   GE_Plannummer
      VARCHAR(12),
   laufende_Nummer_Flurstueck
      VARCHAR(4),
   laufende_Nummer_Teilflaeche
      VARCHAR(2),
   Bemerkung
      VARCHAR(50),
   hat_Nutzungsart
      INTEGER REFERENCES Nutzungsart,
   in_Flurstueck
      INTEGER NOT NULL REFERENCES Kataster.Flurstueck
)

CREATE TABLE Erwerbsart (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Erwerbsart
      VARCHAR(50) NOT NULL,
   GEV_Ausgabespalte
      INTEGER NOT NULL REFERENCES GEV_Ausgabespalte
)

INSERT INTO Erwerbsart VALUES ('?','unbekannt',1)
INSERT INTO Erwerbsart VALUES ('1','zu erwerbende Flche',1)
INSERT INTO Erwerbsart VALUES ('2','vorbergehend in Anspruch zu nehmende Flche',2)
INSERT INTO Erwerbsart VALUES ('3','dauernd zu belastende Flche',3)
INSERT INTO Erwerbsart VALUES ('4','Restflchenerwerb',1)
INSERT INTO Erwerbsart VALUES ('5','rckstndiger Grunderwerb',1)

CREATE TABLE GEV_Ausgabespalte (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Beschreibung
      VARCHAR(255) NOT NULL
)

INSERT INTO GEV_Ausgabespalte VALUES (1,'zu erwerbende Flche')
INSERT INTO GEV_Ausgabespalte VALUES (2,'vorbergehend in Anspruch zu nehmende Flche')
INSERT INTO GEV_Ausgabespalte VALUES (3,'dauernd zu belastende Flche')

CREATE TABLE Erwerbszweck (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Erwerbsart
      VARCHAR(50) NOT NULL
)

INSERT INTO Erwerbszweck VALUES ('?','unbekannt')
INSERT INTO Erwerbszweck VALUES ('A','fr Baulasttrger der Baumanahme Strae')
INSERT INTO Erwerbszweck VALUES ('B','fr Nebenanlagen und Nebenbetriebe')
INSERT INTO Erwerbszweck VALUES ('C','fr Dritte')
INSERT INTO Erwerbszweck VALUES ('D','fr Baulasttrger der Baumanahme LBP')
INSERT INTO Erwerbszweck VALUES ('X','Flchen-/Planungsnderung')
INSERT INTO Erwerbszweck VALUES ('Y','Flche entfllt')

CREATE TABLE Nutzungsart (
   Nutzungsart_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nutzungsartschluessel
      INTEGER NOT NULL,
   Kurztext
      VARCHAR(4),
   Bezeichnung
      VARCHAR(50) NOT NULL
)

CREATE TABLE GE_Massnahme (
   Kennung
      CHAR(10) NOT NULL PRIMARY KEY,
   Massnahmetext
      VARCHAR(200) NOT NULL
)

CREATE TABLE Nutzungsartteilflaeche (
   Nutzungsartteilflaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nutzungsartteilflaeche_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Teilflaeche
      REAL, -- Quadratmeter
   CHECK ( Teilflaeche>=0 ),
   Bodenwert
      REAL, -- EURO
   CHECK ( Bodenwert>=0 ),
   tatsaechliche_Nutzung
      VARCHAR(255),
   rechtliche_Nutzung
      VARCHAR(255),
   hat_Nutzungsart
      INTEGER NOT NULL REFERENCES Nutzungsart,
   von_Flurstueck
      INTEGER NOT NULL REFERENCES Kataster.Flurstueck
)

CREATE TABLE Belastung (
   Belastung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Abteilung
      CHAR(1) NOT NULL,
   laufende_Nummer
      VARCHAR(4),
   Belastungstext
      VARCHAR(200),
   Erlaeuterungen
      VARCHAR(255),
   Eintragung
      CHAR(10), -- Datum
   CHECK ( Eintragung LIKE '__.__.____' ),
   Abloesung
      CHAR(10), -- Datum
   CHECK ( Abloesung LIKE '__.__.____' ),
   Bemerkung
      VARCHAR(200),
   von_Flurstueck
      INTEGER REFERENCES Kataster.Flurstueck,
   in_Grundbuch
      INTEGER REFERENCES Grundbuch
)

CREATE TABLE Belastungsberechtigter (
   Belastungsberechtigter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bemerkung
      VARCHAR(200),
   ist_Person
      INTEGER REFERENCES Person,
   zu_Belastung
      INTEGER REFERENCES Belastung
)

CREATE TABLE Person_Flurstueck (
   Person_Flurstueck_ID
      INTEGER NOT NULL PRIMARY KEY,
   Verhaeltnis
      CHAR(1) REFERENCES Verhaeltnis,
   Bemerkung
      VARCHAR(200),
   Flurstueck
      INTEGER NOT NULL REFERENCES Kataster.Flurstueck,
   Person
      INTEGER NOT NULL REFERENCES Person
)

CREATE TABLE Verhaeltnis (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Verhaeltnis
      VARCHAR(255) NOT NULL
)

INSERT INTO Verhaeltnis VALUES ('V','Verfgungsberechtigter')
INSERT INTO Verhaeltnis VALUES ('A','Alteigentmer')

CREATE TABLE Flurstueck_Grundbuch (
   Flurstueck_Grundbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   GB_Anteil_Zaehler
      INTEGER NOT NULL,
   GB_Anteil_Nenner
      INTEGER NOT NULL,
   Eigentumsart
      CHAR(1) REFERENCES Eigentumsart,
   Bestandsnummer
      VARCHAR(8),
   Bemerkung
      VARCHAR(50),
   Flurstueck
      INTEGER REFERENCES Kataster.Flurstueck,
   Grundbuch
      INTEGER REFERENCES Grundbuch
)

CREATE TABLE Eigentumsart (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Eigentumsart
      VARCHAR(255) NOT NULL
)

INSERT INTO Eigentumsart VALUES ('W','Wohneigentum')
INSERT INTO Eigentumsart VALUES ('E','Erbbaurecht')

CREATE TABLE Grundbuch (
   Grundbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   Band
      VARCHAR(3),
   Blatt
      VARCHAR(6) NOT NULL,
   Bemerkung
      VARCHAR(100),
   zu_Gemarkung
      INTEGER NOT NULL REFERENCES Kataster.Gemarkung
)

CREATE TABLE Paechter_Mieter (
   Paechter_Mieter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Pachtbeginn
      CHAR(10), -- Datum
   CHECK ( Pachtbeginn LIKE '__.__.____' ),
   Pachtende
      CHAR(10), -- Datum
   CHECK ( Pachtende LIKE '__.__.____' ),
   Pachtzins
      REAL, -- EURO
   CHECK ( Pachtzins>=0 ),
   Pachtflaeche
      REAL, -- Quadratmeter
   CHECK ( Pachtflaeche>=0 ),
   Vertragsart
      CHAR(1) REFERENCES Vertragsart,
   Bemerkung
      VARCHAR(100),
   von_Flurstueck
      INTEGER REFERENCES Kataster.Flurstueck,
   zu_Grundbuch
      INTEGER REFERENCES Grundbuch,
   ist_Person
      INTEGER REFERENCES Person,
   hat_Nutzungsart
      INTEGER REFERENCES Nutzungsart
)

CREATE TABLE Vertragsart (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Vertragsart
      VARCHAR(255) NOT NULL
)

INSERT INTO Vertragsart VALUES ('s','schriftlich')
INSERT INTO Vertragsart VALUES ('m','mndlich')

CREATE TABLE Eigentuemer_Grundbuch (
   Eigentuemer_Grundbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   Eigentumsverhaeltnis
      CHAR(1) REFERENCES Eigentumsverhaeltnis,
   ET_Anteil_Zaehler
      INTEGER NOT NULL,
   ET_Anteil_Nenner
      INTEGER NOT NULL,
   Bemerkung
      VARCHAR(50),
   von_Grundbuch
      INTEGER NOT NULL REFERENCES Grundbuch,
   ist_Person
      INTEGER NOT NULL REFERENCES Person
)

CREATE TABLE Eigentumsverhaeltnis (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Eigentumsverhaeltnis
      VARCHAR(255) NOT NULL
)

INSERT INTO Eigentumsverhaeltnis VALUES ('A','Alleineigentmer')
INSERT INTO Eigentumsverhaeltnis VALUES ('M','Miteigentmer')
INSERT INTO Eigentumsverhaeltnis VALUES ('U','Ungeteilte Gemeinschaft')
INSERT INTO Eigentumsverhaeltnis VALUES ('G','Geteilte Gemeinschaft')

CREATE TABLE Person (
   Person_ID
      INTEGER NOT NULL PRIMARY KEY,
   Personenklasse
      CHAR(1) REFERENCES Personenklasse,
   Titel
      VARCHAR(32),
   Name
      VARCHAR(64) NOT NULL,
   Vorname
      VARCHAR(48),
   Strasse
      VARCHAR(48),
   Plz
      VARCHAR(10),
   Ort
      VARCHAR(48),
   Land
      CHAR(3) REFERENCES Land,
   Geburtsdatum
      CHAR(10), -- Datum
   CHECK ( Geburtsdatum LIKE '__.__.____' ),
   Geburtsname
      VARCHAR(64),
   Anrede
      VARCHAR(50),
   Telefon
      VARCHAR(20),
   Telefax
      VARCHAR(20),
   Bemerkung
      VARCHAR(100)
)

CREATE TABLE Land (
   Kennung
      CHAR(3) NOT NULL PRIMARY KEY,
   Land
      VARCHAR(255) NOT NULL
)

INSERT INTO Land VALUES ('AFG','Afghanistan')
INSERT INTO Land VALUES ('AL','Albanien')
INSERT INTO Land VALUES ('AND','Andora')
INSERT INTO Land VALUES ('RA','Argentinien')
INSERT INTO Land VALUES ('AZ','Aserbaidschan')
INSERT INTO Land VALUES ('AUS','Australien')
INSERT INTO Land VALUES ('BS','Bahamas')
INSERT INTO Land VALUES ('BRN','Bahrain')
INSERT INTO Land VALUES ('BD','Bangladesch')
INSERT INTO Land VALUES ('BDS','Barbados')
INSERT INTO Land VALUES ('BY','Belanus')
INSERT INTO Land VALUES ('B','Belgien')
INSERT INTO Land VALUES ('BH','Belize')
INSERT INTO Land VALUES ('BOL','Bolivien')
INSERT INTO Land VALUES ('BIH','Bosnien-Herzegowina')
INSERT INTO Land VALUES ('BR','Brasilien')
INSERT INTO Land VALUES ('BRU','Brunei Darussalam')
INSERT INTO Land VALUES ('BG','Bulgarien')
INSERT INTO Land VALUES ('BF','Burkina Faso')
INSERT INTO Land VALUES ('CA','Canada')
INSERT INTO Land VALUES ('DK','Dnemark')
INSERT INTO Land VALUES ('D','Deutschland')
INSERT INTO Land VALUES ('FIN','Finnland')
INSERT INTO Land VALUES ('F','Frankreich')
INSERT INTO Land VALUES ('GR','Griechenland')
INSERT INTO Land VALUES ('GB','Grobritannien')
INSERT INTO Land VALUES ('IRL','Irland')
INSERT INTO Land VALUES ('IS','Island')
INSERT INTO Land VALUES ('IL','Israel')
INSERT INTO Land VALUES ('I','Italien')
INSERT INTO Land VALUES ('J','Japan')
INSERT INTO Land VALUES ('CDN','Kanada')
INSERT INTO Land VALUES ('C','Kuba')
INSERT INTO Land VALUES ('LT','Litauen')
INSERT INTO Land VALUES ('L','Luxenburg')
INSERT INTO Land VALUES ('M','Malta')
INSERT INTO Land VALUES ('MA','Marokko')
INSERT INTO Land VALUES ('MEX','Mexiko')
INSERT INTO Land VALUES ('MC','Monaco')
INSERT INTO Land VALUES ('N','Norwegen')
INSERT INTO Land VALUES ('A','sterreich')
INSERT INTO Land VALUES ('PL','Polen')
INSERT INTO Land VALUES ('P','Portugal')
INSERT INTO Land VALUES ('S','Schweden')
INSERT INTO Land VALUES ('CH','Schweiz')
INSERT INTO Land VALUES ('SLO','Slowenien')
INSERT INTO Land VALUES ('E','Spanien')
INSERT INTO Land VALUES ('ZA','Sdafrika')
INSERT INTO Land VALUES ('TR','Trkei')
INSERT INTO Land VALUES ('H','Ungarn')
INSERT INTO Land VALUES ('USA','Vereinigte Staaten')

CREATE TABLE Personenklasse (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Personenklasse
      VARCHAR(255) NOT NULL
)

INSERT INTO Personenklasse VALUES ('?','unbekannt')
INSERT INTO Personenklasse VALUES ('G','Gemeindeverwaltung')
INSERT INTO Personenklasse VALUES ('J','juristische Person')
INSERT INTO Personenklasse VALUES ('L','Landwirtschaftsamt')
INSERT INTO Personenklasse VALUES ('N','natrliche Person')
INSERT INTO Personenklasse VALUES ('','ffentlicher Bedarfstrger')
INSERT INTO Personenklasse VALUES ('V','verstorben')

